{*
 *******************************************************************************
 *
 *  Copyright 2025 RIEGL Laser Measurement Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 *******************************************************************************
 *}
{*!
 *******************************************************************************
 *
 * \author  RIEGL LMS GmbH, Austria
 * \brief   Description of RIEGL RDB 2 database meta data items.
 * \version 2015-10-27/AW: Initial version
 * \version 2015-11-25/AW: Item "Geo Tag" added
 * \version 2016-10-27/AW: Item "Voxel Information" added
 * \version 2016-11-17/AW: Item "Voxel Information" updated
 * \version 2016-12-12/AW: Item "Range Statistics" added
 * \version 2017-03-08/AW: Item "Plane Patch Statistics" added
 * \version 2017-04-05/AW: Items "Atmosphere" and "Geometric Scale Factor" added
 * \version 2017-08-22/AW: Items for waveform sample block and value files added
 * \version 2017-10-24/AW: Item "Gaussian Decomposition" added
 * \version 2017-11-13/AW: Item "riegl.scan_pattern" updated
 * \version 2017-11-21/AW: Item "riegl.trajectory_info" added
 * \version 2018-01-11/AW: Item "riegl.beam_geometry" added
 * \version 2018-01-15/AW: Item "riegl.reflectance_calculation" added
 * \version 2018-01-15/AW: Item "riegl.near_range_correction" added
 * \version 2018-01-15/AW: Item "riegl.device_geometry" added
 * \version 2018-02-13/AW: Item "riegl.notch_filter" added
 * \version 2018-03-08/AW: Item "riegl.window_echo_correction" added
 * \version 2018-03-15/AW: Item "riegl.pulse_position_modulation" added
 * \version 2018-05-24/AW: Item "riegl.pixel_info" added
 * \version 2018-06-08/AW: Item "riegl.shot_info" added
 * \version 2018-06-08/AW: Item "riegl.echo_info" added
 * \version 2018-06-14/AW: Item "riegl.mta_settings" added
 * \version 2018-06-14/AW: Item "riegl.receiver_internals" added
 * \version 2018-06-14/AW: Item "riegl.device_output_limits" added
 * \version 2018-06-26/AW: Schema: replace "number" with "integer" if applicable
 * \version 2018-07-09/AW: Item "riegl.pose_estimation" added
 * \version 2018-07-09/AW: Item "riegl.pose_sensors" added
 * \version 2018-09-20/AW: Item "riegl.pointcloud_info" added
 * \version 2018-11-08/AW: Item "riegl.scan_pattern" updated
 * \version 2018-11-13/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-06/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-21/AW: Item "riegl.device_geometry" updated
 * \version 2019-04-15/AW: Item "riegl.point_attribute_groups" added
 * \version 2019-04-30/AW: Item "riegl.waveform_settings" added
 * \version 2019-10-03/AW: Item "riegl.angular_notch_filter" added
 * \version 2019-10-03/AW: Item "riegl.noise_estimates" added
 * \version 2019-10-25/AW: Item "riegl.window_analysis" added
 * \version 2019-11-06/AW: Item "riegl.georeferencing_parameters" added
 * \version 2019-11-27/AW: Item "riegl.plane_patch_matching" added
 * \version 2019-12-13/AW: Items for tie-/control objects added
 * \version 2019-12-19/AW: Items for tie-/control objects added
 * \version 2020-02-04/AW: Item "riegl.detection_probability" added
 * \version 2020-02-04/AW: Item "riegl.licenses" added
 * \version 2020-04-27/AW: Item "riegl.waveform_info" updated (schema+example)
 * \version 2020-09-03/AW: Item "riegl.reflectance_correction" added
 * \version 2020-09-10/AW: Item "riegl.device_geometry_passive_channel" added
 * \version 2020-09-25/AW: Item "riegl.georeferencing_parameters" updated
 * \version 2020-09-25/AW: Item "riegl.trajectory_info" updated
 * \version 2020-09-29/AW: Item "riegl.temperature_calculation" added
 * \version 2020-10-23/AW: Item "riegl.exponential_decomposition" added (#3709)
 * \version 2020-11-30/AW: Item "riegl.notch_filter" updated (schema)
 * \version 2020-12-02/AW: Item "riegl.georeferencing_parameters" updated (schema)
 * \version 2021-02-02/AW: Item "riegl.plane_slope_class_info" added (rdbplanes/#7)
 * \version 2021-02-16/AW: Item "riegl.device_output_limits" updated (schema, #3811)
 * \version 2021-03-03/AW: Item "riegl.exponential_decomposition" updated (schema, #3822)
 * \version 2021-03-03/AW: Item "riegl.waveform_averaging_settings" added (#3821)
 * \version 2021-04-01/AW: Item "riegl.voxel_info" updated (schema, #3854)
 * \version 2021-04-16/AW: Item "riegl.voxel_info" updated (schema, #3866)
 * \version 2021-09-30/AW: Item "riegl.waveform_info" updated (schema+example, #4016)
 * \version 2021-10-04/AW: Improved spelling of the descriptions of some items
 * \version 2021-11-04/AW: Rename "riegl.record_names" to "riegl.item_names" (#4034)
 * \version 2022-03-11/AW: Item "riegl.devices" added (#4162)
 * \version 2022-03-14/AW: Item "riegl.stored_filters" added (#4164)
 * \version 2022-09-20/AW: Fix typos in schema of "riegl.georeferencing_parameters"
 * \version 2022-09-30/AW: Item "riegl.system_description" added (#4368)
 * \version 2022-10-10/AW: Correction of typos in the titles of some entries
 * \version 2022-10-20/AW: Item "riegl.stored_filters" updated (example, #4164)
 * \version 2023-01-19/AW: Item "riegl.ttip_configuration" added (#4449)
 * \version 2024-09-26/AW: Item "riegl.dyntrig" added (#5310)
 *
 *******************************************************************************
 *}

unit riegl.rdb.default.metadata;

{$WRITEABLECONST ON} // see section "initialization"

interface

// Meta data items definition version
const
  RDB_META_DATA_ITEMS_VERSION = '1.1.54';
  RDB_META_DATA_ITEMS_DATE = '2023-01-19';

// Meta data item states
const
  RDB_STATUS_REQUIRED = 1; // mandatory item
  RDB_STATUS_OPTIONAL = 2; // optional item

// Container record for meta data item details
type
  TRDBPointcloudMetaDataItemInfo = record
    Name        : System.String;
    Title       : System.String;
    Description : System.String;
    Status      : System.Byte;
    Schema      : System.String;
    Example     : System.String;
  end;
  PRDBPointcloudMetaDataItemInfo = ^TRDBPointcloudMetaDataItemInfo;

// Angular notch filter parameters for window glass echoes
const
  RDB_RIEGL_ANGULAR_NOTCH_FILTER : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.angular_notch_filter';
    Title       : 'Angular Notch Filter';
    Description : 'Angular notch filter parameters for window glass echoes';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Angular Notch Filter","type":"object","$schema":"http://json'
      + '-schema.org/draft-04/schema#","required":["angle","range_mean","amplit'
      + 'ude_mean"],"properties":{"amplitude_mean":{"type":"array","items":{"ty'
      + 'pe":"number"},"description":"Mean amplitude [dB]"},"angle":{"type":"ar'
      + 'ray","items":{"type":"number"},"description":"Angle [deg]"},"range_mea'
      + 'n":{"type":"array","items":{"type":"number"},"description":"Mean range'
      + ' [m]"}},"description":"Angular notch filter parameters for window '
      + 'glass echoes"}'
    );

    Example : (''
      + '{"amplitude_mean":[3.780913,3.780913,3.480913,3.120913,2.850913,2.7209'
      + '13,2.680913,2.610913,2.530913,2.570913,2.570913],"angle":[14.0,15.0,16'
      + '.0,17.0,18.0,19.0,20.0,21.0,22.0,23.0,24.0],"range_mean":[0.094,0.094,'
      + '0.09075,0.08675,0.0815,0.0775,0.074,0.071,0.068,0.0675,0.06475]}'
    );
  );

// Atmospheric parameters
const
  RDB_RIEGL_ATMOSPHERE : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.atmosphere';
    Title       : 'Atmosphere';
    Description : 'Atmospheric parameters';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Atmospheric Parameters","type":"object","$schema":"http://js'
      + 'on-schema.org/draft-04/schema#","required":["temperature","pressure","'
      + 'rel_humidity","pressure_sl","amsl","group_velocity","attenuation","wav'
      + 'elength"],"properties":{"wavelength":{"type":"number","description":"L'
      + 'aser wavelength '
      + '[nm]"},"attenuation":{"type":"number","description":"Atmospheric '
      + 'attenuation '
      + '[1/km]"},"group_velocity":{"type":"number","description":"Group '
      + 'velocity of laser beam '
      + '[m/s]"},"pressure":{"type":"number","description":"Pressure along '
      + 'measurment path '
      + '[mbar]"},"temperature":{"type":"number","description":"Temperature '
      + 'along measurement path '
      + '[\u00b0C]"},"pressure_sl":{"type":"number","description":"Atmospheric '
      + 'pressure at sea level '
      + '[mbar]"},"rel_humidity":{"type":"number","description":"Relative '
      + 'humidity along measurement path '
      + '[%]"},"amsl":{"type":"number","description":"Height above mean sea '
      + 'level (AMSL) [m]"}},"description":"Atmospheric parameters"}'
    );

    Example : (''
      + '{"wavelength":1550,"attenuation":0.028125,"group_velocity":299711000.0'
      + ',"pressure":970,"temperature":7,"pressure_sl":970,"rel_humidity":63,"a'
      + 'msl":0}'
    );
  );

// Laser beam geometry details
const
  RDB_RIEGL_BEAM_GEOMETRY : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.beam_geometry';
    Title       : 'Beam Geometry';
    Description : 'Laser beam geometry details';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Beam Geometry","type":"object","$schema":"http://json-schema'
      + '.org/draft-04/schema#","required":["beam_exit_diameter","beam_divergen'
      + 'ce"],"properties":{"beam_divergence":{"minimum":0,"description":"Beam '
      + 'divergence in far field [rad]","exclusiveMinimum":false,"type":"number'
      + '"},"beam_exit_diameter":{"minimum":0,"description":"Beam width at exit'
      + ' aperture '
      + '[m]","exclusiveMinimum":false,"type":"number"}},"description":"Laser '
      + 'beam geometry details"}'
    );

    Example : (''
      + '{"beam_divergence":0.0003,"beam_exit_diameter":0.0072}'
    );
  );

// List of control object type definitions
const
  RDB_RIEGL_CONTROL_OBJECT_CATALOG : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.control_object_catalog';
    Title       : 'Control Object Catalog';
    Description : 'List of control object type definitions';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Control Object Catalog","required":["types"],"type":"object"'
      + ',"$schema":"http://json-schema.org/draft-04/schema#","definitions":{"s'
      + 'phere":{"description":"sphere","allOf":[{"$ref":"#/definitions/common"'
      + '},{"description":"sphere specific properties","required":["shape","dia'
      + 'meter"],"properties":{"diameter":{"minimum":0,"description":"diameter '
      + 'in meters","exclusiveMinimum":true,"type":"number"},"shape":{"descript'
      + 'ion":"shape identifier","enum":["sphere"],"type":"string"}},"type":"ob'
      + 'ject"}],"type":"object"},"checkerboard2x2":{"description":"checkerboar'
      + 'd 2 by 2","allOf":[{"$ref":"#/definitions/common"},{"description":"che'
      + 'ckerboard specific properties","required":["shape","square_length"],"p'
      + 'roperties":{"square_length":{"minimum":0,"description":"length of a '
      + 'square of the checkerboard in meters","exclusiveMinimum":true,"type":"'
      + 'number"},"shape":{"description":"shape identifier","enum":["checkerboa'
      + 'rd2x2"],"type":"string"}},"type":"object"}],"type":"object"},"round_co'
      + 'rner_cube_prism":{"description":"round corner cube '
      + 'prism","allOf":[{"$ref":"#/definitions/common"},{"description":"round '
      + 'corner cube prism specific properties","required":["shape","diameter"]'
      + ',"properties":{"diameter":{"minimum":0,"description":"diameter in mete'
      + 'rs","exclusiveMinimum":true,"type":"number"},"offset":{"description":"'
      + 'offset in meters, e.g. reflector constant '
      + '(optional)","type":"number"},"shape":{"description":"shape identifier"'
      + ',"enum":["round_corner_cube_prism"],"type":"string"}},"type":"object"}'
      + '],"type":"object"},"cylinder":{"description":"cylinder","allOf":[{"$re'
      + 'f":"#/definitions/common"},{"description":"cylinder specific propertie'
      + 's","required":["shape","diameter","height"],"properties":{"diameter":{'
      + '"minimum":0,"description":"diameter in meters","exclusiveMinimum":true'
      + ',"type":"number"},"height":{"minimum":0,"description":"height in meter'
      + 's","exclusiveMinimum":true,"type":"number"},"shape":{"description":"sh'
      + 'ape identifier","enum":["cylinder"],"type":"string"}},"type":"object"}'
      + '],"type":"object"},"common":{"description":"common object properties",'
      + '"required":["name","shape"],"properties":{"name":{"minLength":3,"descr'
      + 'iption":"unique type '
      + 'identifier","type":"string"},"shape":{"description":"shape identifier"'
      + ',"enum":["rectangle","checkerboard2x2","chevron","circular_disk","cyli'
      + 'nder","sphere","round_corner_cube_prism"],"type":"string"},"surface_ty'
      + 'pe":{"description":"surface material type","enum":["retro_reflective_f'
      + 'oil","diffuse"],"type":"string"},"description":{"description":"string '
      + 'describing the object","type":"string"}},"type":"object"},"chevron":{"'
      + 'description":"chevron","allOf":[{"$ref":"#/definitions/common"},{"desc'
      + 'ription":"chevron specific properties","required":["shape","outside_ed'
      + 'ge_length","thickness"],"properties":{"thickness":{"minimum":0,"descri'
      + 'ption":"thickness in meters","exclusiveMinimum":true,"type":"number"},'
      + '"outside_edge_length":{"minimum":0,"description":"length of the two '
      + 'outer edges in meters","exclusiveMinimum":true,"type":"number"},"shape'
      + '":{"description":"shape identifier","enum":["chevron"],"type":"string"'
      + '}},"type":"object"}],"type":"object"},"rectangle":{"description":"rect'
      + 'angle","allOf":[{"$ref":"#/definitions/common"},{"description":"rectan'
      + 'gle specific properties","required":["shape","length","width"],"proper'
      + 'ties":{"length":{"minimum":0,"description":"length in meters","exclusi'
      + 'veMinimum":true,"type":"number"},"width":{"minimum":0,"description":"w'
      + 'idth in meters","exclusiveMinimum":true,"type":"number"},"shape":{"typ'
      + 'e":"string","enum":["rectangle"]}},"type":"object"}],"type":"object"},'
      + '"circular_disk":{"description":"circular disk","allOf":[{"$ref":"#/def'
      + 'initions/common"},{"description":"circular disk specific properties","'
      + 'required":["shape","diameter"],"properties":{"diameter":{"minimum":0,"'
      + 'description":"diameter in meters","exclusiveMinimum":true,"type":"numb'
      + 'er"},"offset":{"description":"offset in meters, e.g. reflector '
      + 'constant (optional)","type":"number"},"shape":{"description":"shape id'
      + 'entifier","enum":["circular_disk"],"type":"string"}},"type":"object"}]'
      + ',"type":"object"}},"properties":{"types":{"uniqueItems":true,"type":"a'
      + 'rray","items":{"type":"object","oneOf":[{"$ref":"#/definitions/rectang'
      + 'le"},{"$ref":"#/definitions/checkerboard2x2"},{"$ref":"#/definitions/c'
      + 'hevron"},{"$ref":"#/definitions/circular_disk"},{"$ref":"#/definitions'
      + '/cylinder"},{"$ref":"#/definitions/sphere"},{"$ref":"#/definitions/rou'
      + 'nd_corner_cube_prism"}]}}},"description":"List of control object type '
      + 'definitions"}'
    );

    Example : (''
      + '{"comments":["This file contains a list of control object types (aka. '
      + '''catalog'').","Each type is described by an object,","which must '
      + 'contain at least the following parameters:","  - name: unique '
      + 'identifier of the type","  - shape: one of the following supported '
      + 'shapes:","      - rectangle","      - checkerboard2x2","      - '
      + 'chevron","      - circular_disk","      - cylinder","      - sphere","'
      + '      - round_corner_cube_prism","Depending on ''shape'', the following '
      + 'parameters must/may be specified:","  - rectangle:","      - length: '
      + 'length in meters","      - width: width in meters","  - '
      + 'checkerboard2x2:","      - square_length: length of a square of the '
      + 'checkerboard in meters","  - circular_disk:","      - diameter: '
      + 'diameter in meters","      - offset: offset in meters, e.g. reflector '
      + 'constant (optional)","  - chevron:","      - outside_edge_length: '
      + 'length of the two outer edges in meters","      - thickness: thickness'
      + ' in meters","  - cylinder:","      - diameter: diameter in meters","'
      + '      - height: height in meters","  - sphere:","      - diameter: '
      + 'diameter in meters","  - round_corner_cube_prism:","      - diameter: '
      + 'diameter in meters","      - offset: offset in meters, e.g. reflector '
      + 'constant (optional)","Optional parameters:","    - description: string'
      + ' describing the object","    - surface_type: surface material type '
      + '(either ''retro_reflective_foil'' or '
      + '''diffuse'')"],"types":[{"name":"Rectangle 60x30","shape":"rectangle","l'
      + 'ength":0.6,"width":0.3,"description":"Rectangle (60cm x '
      + '30cm)"},{"name":"Rectangle 80x40","shape":"rectangle","length":0.8,"wi'
      + 'dth":0.4,"description":"Rectangle (80cm x '
      + '40cm)"},{"name":"Checkerboard2x2 30","shape":"checkerboard2x2","square'
      + '_length":0.3,"description":"Checkerboard (square length: '
      + '30cm)"},{"name":"Checkerboard2x2 50","shape":"checkerboard2x2","square'
      + '_length":0.5,"description":"Checkerboard (square length: '
      + '50cm)"},{"thickness":0.1016,"name":"Chevron 24''''/4''''","shape":"chevron'
      + '","outside_edge_length":0.6096,"description":"Chevron (a=24''''; '
      + 'b=4'''')"},{"name":"Circular Disk 50","diameter":0.5,"shape":"circular_d'
      + 'isk","surface_type":"diffuse","description":" Circular Disk (diameter:'
      + ' 50cm)"},{"name":"RIEGL flat reflector 50 mm","diameter":0.05,"surface'
      + '_type":"retro_reflective_foil","description":"flat circular reflector '
      + 'from retro-reflective '
      + 'foil","offset":0.0,"shape":"circular_disk"},{"name":"RIEGL flat '
      + 'reflector 100 mm","diameter":0.1,"surface_type":"retro_reflective_foil'
      + '","description":"flat circular reflector from retro-reflective '
      + 'foil","offset":0.0,"shape":"circular_disk"},{"name":"RIEGL flat '
      + 'reflector 150 mm","diameter":0.15,"surface_type":"retro_reflective_foi'
      + 'l","description":"flat circular reflector from retro-reflective '
      + 'foil","offset":0.0,"shape":"circular_disk"},{"name":"RIEGL cylindrical'
      + ' reflector 50 mm","diameter":0.05,"surface_type":"retro_reflective_foi'
      + 'l","description":"cylindrical reflector from retro-reflective '
      + 'foil","height":0.05,"shape":"cylinder"},{"name":"RIEGL cylindrical '
      + 'reflector 100 mm","diameter":0.1,"surface_type":"retro_reflective_foil'
      + '","description":"cylindrical reflector from retro-reflective '
      + 'foil","height":0.1,"shape":"cylinder"},{"name":"Sphere 200 '
      + 'mm","diameter":0.2,"shape":"sphere","description":"Sphere (diameter: '
      + '200 mm)"},{"name":"Corner Cube Prism 50 mm","diameter":0.05,"shape":"r'
      + 'ound_corner_cube_prism","offset":0.0,"description":"round corner cube '
      + 'prism"}]}'
    );
  );

// Details about the control object reference file
const
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.control_object_reference_file';
    Title       : 'Control Object Reference file';
    Description : 'Details about the control object reference file';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","title":"Control '
      + 'Object Reference file","properties":{"reference_file":{"type":"object"'
      + ',"required":["file_uuid","file_path"],"properties":{"file_path":{"desc'
      + 'ription":"Path of the control object file relative to referring '
      + 'file","type":"string"},"file_uuid":{"description":"Control object '
      + 'file''s Universally Unique Identifier (RFC '
      + '4122)","type":"string"}},"description":"Reference to a control object '
      + 'file"}},"type":"object","description":"Details about the control '
      + 'object reference file"}'
    );

    Example : (''
      + '{"reference_file":{"file_path":"../../../10_CONTROL_OBJECTS/ControlPoi'
      + 'nts.cpx","file_uuid":"810f5d57-eccf-49ed-b07a-0cdd109b4213"}}'
    );
  );

// Detection probability as a function of amplitude
const
  RDB_RIEGL_DETECTION_PROBABILITY : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.detection_probability';
    Title       : 'Detection Probability';
    Description : 'Detection probability as a function of amplitude';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Detection Probability","type":"object","$schema":"http://jso'
      + 'n-schema.org/draft-04/schema#","required":["amplitude","detection_prob'
      + 'ability"],"properties":{"amplitude":{"type":"array","items":{"type":"n'
      + 'umber"},"description":"Amplitude [dB]"},"detection_probability":{"type'
      + '":"array","items":{"type":"number"},"description":"Detection '
      + 'probability [0..1]"}},"description":"Detection probability as a '
      + 'function of amplitude"}'
    );

    Example : (''
      + '{"amplitude":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0],"detection'
      + '_probability":[0.0,0.5,0.8,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]}'
    );
  );

// Details about the device used to acquire the point cloud
const
  RDB_RIEGL_DEVICE : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.device';
    Title       : 'Device Information';
    Description : 'Details about the device used to acquire the point cloud';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Device Information","type":"object","$schema":"http://json-s'
      + 'chema.org/draft-04/schema#","required":["device_type","serial_number"]'
      + ',"properties":{"serial_number":{"description":"Device serial number '
      + '(e.g. '
      + 'S2221234)","type":"string"},"device_name":{"description":"Optional '
      + 'device name (e.g. ''Scanner 1'' for multi-scanner '
      + 'systems)","type":"string"},"device_type":{"description":"Device type '
      + 'identifier (e.g. VZ-400i)","type":"string"},"channel_number":{"minimum'
      + '":0,"description":"Laser channel number (not defined or 0: single '
      + 'channel device)","exclusiveMinimum":false,"type":"integer"},"device_bu'
      + 'ild":{"description":"Device build '
      + 'variant","type":"string"},"channel_text":{"description":"Optional '
      + 'channel description (e.g. ''Green Channel'' for multi-channel '
      + 'devices)","type":"string"}},"description":"Details about the device '
      + 'used to acquire the point cloud"}'
    );

    Example : (''
      + '{"serial_number":"S2221234","device_name":"Scanner 1","device_type":"V'
      + 'Z-400i","channel_number":0,"device_build":"","channel_text":""}'
    );
  );

// Scanner device geometry details
const
  RDB_RIEGL_DEVICE_GEOMETRY : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.device_geometry';
    Title       : 'Device Geometry';
    Description : 'Scanner device geometry details';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Device Geometry","type":"object","$schema":"http://json-sche'
      + 'ma.org/draft-04/schema#","required":["primary"],"properties":{"seconda'
      + 'ry":{"description":"Additional device geometry structure (optional)","'
      + 'required":["ID","content"],"properties":{"content":{"description":"Int'
      + 'ernal calibration values","items":{"type":"number"},"type":"array"},"I'
      + 'D":{"description":"Structure identifier","minItems":2,"items":{"type":'
      + '"integer"},"maxItems":2,"type":"array"}},"type":"object"},"primary":{"'
      + 'description":"Primary device geometry structure (mandatory)","required'
      + '":["ID","content"],"properties":{"content":{"description":"Internal '
      + 'calibration values","items":{"type":"number"},"type":"array"},"ID":{"d'
      + 'escription":"Structure identifier","minItems":2,"items":{"type":"integ'
      + 'er"},"maxItems":2,"type":"array"}},"type":"object"},"amu":{"descriptio'
      + 'n":"Angle Measurement '
      + 'Unit","properties":{"lineCC":{"minimum":0,"description":"Line Circle '
      + 'Count (number of LSBs per full rotation about line axis)","exclusiveMi'
      + 'nimum":false,"type":"number"},"frameCC":{"minimum":0,"description":"Fr'
      + 'ame Circle Count (number of LSBs per full rotation about frame axis)",'
      + '"exclusiveMinimum":false,"type":"number"}},"type":"object"}},"descript'
      + 'ion":"Scanner device geometry details"}'
    );

    Example : (''
      + '{"secondary":{"content":[0],"ID":[91,0]},"primary":{"content":[0],"ID"'
      + ':[4,0]},"amu":{"lineCC":124000,"frameCC":124000}}'
    );
  );

// Scanner passive channel device geometry details
const
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.device_geometry_passive_channel';
    Title       : 'Device Geometry Passive Channel';
    Description : 'Scanner passive channel device geometry details';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Device Geometry Passive Channel","type":"object","$schema":"'
      + 'http://json-schema.org/draft-04/schema#","required":["primary"],"prope'
      + 'rties":{"primary":{"description":"Primary device geometry structure (m'
      + 'andatory)","required":["ID","content"],"properties":{"content":{"descr'
      + 'iption":"Internal calibration values","items":{"type":"number"},"type"'
      + ':"array"},"ID":{"description":"Structure identifier","minItems":2,"ite'
      + 'ms":{"type":"integer"},"maxItems":2,"type":"array"}},"type":"object"}}'
      + ',"description":"Scanner passive channel device geometry details"}'
    );

    Example : (''
      + '{"primary":{"content":[0],"ID":[143,0]}}'
    );
  );

// Limits of the measured values output by the device
const
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.device_output_limits';
    Title       : 'Device Output Limits';
    Description : 'Limits of the measured values output by the device';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","title":"Device '
      + 'Output Limits","properties":{"amplitude_minimum":{"type":"number","des'
      + 'cription":"Minimum possible amplitude in '
      + 'dB."},"deviation_maximum":{"type":"number","description":"Maximum '
      + 'possible pulse shape deviation."},"background_radiation_minimum":{"typ'
      + 'e":"number","description":"Minimum possible background radiation."},"m'
      + 'ta_zone_count_maximum":{"type":"number","description":"Maximum number '
      + 'of MTA '
      + 'zones."},"range_maximum":{"type":"number","description":"Maximum '
      + 'possible range in '
      + 'meters."},"echo_count_maximum":{"type":"number","description":"Maximum'
      + ' number of echoes a laser shot can have."},"background_radiation_maxim'
      + 'um":{"type":"number","description":"Maximum possible background radiat'
      + 'ion."},"amplitude_maximum":{"type":"number","description":"Maximum '
      + 'possible amplitude in '
      + 'dB."},"range_minimum":{"type":"number","description":"Minimum possible'
      + ' range in '
      + 'meters."},"deviation_minimum":{"type":"number","description":"Minimum '
      + 'possible pulse shape deviation."},"reflectance_minimum":{"type":"numbe'
      + 'r","description":"Minimum possible reflectance in '
      + 'dB."},"reflectance_maximum":{"type":"number","description":"Maximum '
      + 'possible reflectance in dB."}},"type":"object","description":"Limits '
      + 'of the measured values output by the device. The limits depend on the '
      + 'device type, measurement program and/or scan pattern."}'
    );

    Example : (''
      + '{"amplitude_minimum":0.0,"mta_zone_count_maximum":7,"deviation_minimum'
      + '":-1,"amplitude_maximum":100.0,"deviation_maximum":32767,"range_maximu'
      + 'm":10000.0,"range_minimum":2.9,"background_radiation_maximum":0,"refle'
      + 'ctance_minimum":-100.0,"background_radiation_minimum":0,"reflectance_m'
      + 'aximum":100.0}'
    );
  );

// Details about the devices used to acquire the point cloud
const
  RDB_RIEGL_DEVICES : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.devices';
    Title       : 'Devices Information';
    Description : 'Details about the devices used to acquire the point cloud';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","title":"Devices '
      + 'Information","items":{"type":"object","properties":{"serial_number":{"'
      + 'description":"Device serial number (e.g. '
      + 'S2221234)","type":"string"},"device_name":{"description":"Optional '
      + 'device name (e.g. ''Scanner 1'' for multi-scanner '
      + 'systems)","type":"string"},"device_type":{"description":"Device type '
      + 'identifier (e.g. VZ-400i)","type":"string"},"channel_number":{"minimum'
      + '":0,"description":"Laser channel number (not defined or 0: single '
      + 'channel device)","exclusiveMinimum":false,"type":"integer"},"device_bu'
      + 'ild":{"description":"Device build '
      + 'variant","type":"string"},"channel_text":{"description":"Optional '
      + 'channel description (e.g. ''Green Channel'' for multi-channel '
      + 'devices)","type":"string"},"signed":{"description":"Flag that is set '
      + 'when the original ''riegl.device'' entry in the source file was '
      + 'correctly signed.","type":"boolean"}},"required":["device_type","seria'
      + 'l_number"]},"type":"array","description":"Details about the devices '
      + 'used to acquire the point cloud (e.g. when merging point clouds of '
      + 'different devices)"}'
    );

    Example : (''
      + '[{"serial_number":"S2221234","device_name":"Scanner 1","device_type":"'
      + 'VZ-400i","channel_number":0,"device_build":"","channel_text":"","signe'
      + 'd":false},{"serial_number":"S2222680","device_name":"Scanner 2","devic'
      + 'e_type":"VQ-1560i-DW","channel_number":1,"device_build":"","channel_te'
      + 'xt":"","signed":true},{"serial_number":"S2222680","device_name":"Scann'
      + 'er 3","device_type":"VQ-1560i-DW","channel_number":2,"device_build":""'
      + ',"channel_text":"","signed":true}]'
    );
  );

// Dyntrig
const
  RDB_RIEGL_DYNTRIG : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.dyntrig';
    Title       : 'Dyntrig';
    Description : 'Dyntrig';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","title":"Dyntrig"'
      + ',"properties":{"pre":{"type":"object","required":["nc","a"],"propertie'
      + 's":{"a":{"description":"...","type":"array","minItems":1,"maxItems":20'
      + '80,"items":{"type":"number"}},"nc":{"minimum":0,"type":"integer","maxi'
      + 'mum":255,"description":"Number of entries"}},"description":"Dyntrig '
      + 'pre values"},"offset":{"type":"number","description":"Offset in units '
      + 'of dB, for calculation of '
      + 'line"},"scale":{"type":"number","description":"Scale in units of dB, '
      + 'for calculation of line: line number N=(amplitude-offset)/scale"},"tab'
      + '":{"description":"...","type":"array","minItems":1,"maxItems":128,"ite'
      + 'ms":{"description":"...","required":["thra1","del1","dec1","thra2","de'
      + 'l2","dec2"],"properties":{"dec1":{"description":"Decay of post-trigger'
      + ' threshold after del1 in units of '
      + 'dB/m","type":"number"},"thra2":{"description":"Pre-trigger threshold '
      + 'in units of dB","type":"number"},"dec2":{"description":"Rise of '
      + 'pre-trigger threshold after del2 in units of '
      + 'dB/m","type":"number"},"thra1":{"description":"Post-trigger threshold '
      + 'in units of dB","type":"number"},"del2":{"description":"Length of '
      + 'constant pre-trigger threshold elevation in units of '
      + 'm","type":"number"},"del1":{"description":"Length of constant '
      + 'post-trigger threshold elevation in units of m","type":"number"}},"typ'
      + 'e":"object"}},"post":{"type":"object","required":["nc","a"],"propertie'
      + 's":{"a":{"description":"...","type":"array","minItems":1,"maxItems":20'
      + '80,"items":{"type":"number"}},"nc":{"minimum":0,"type":"integer","maxi'
      + 'mum":255,"description":"Number of entries"}},"description":"Dyntrig '
      + 'post values"}},"description":"Dyntrig"}'
    );

    Example : (''
      + '{"pre":{"a":[78,86,126,134,31],"nc":128},"offset":0.0,"scale":1.0,"tab'
      + '":[{"dec1":0.0,"thra2":0.0,"dec2":0.0,"thra1":0.0,"del2":0.0,"del1":0.'
      + '0}],"post":{"a":[78,86,126,134,31],"nc":128}}'
    );
  );

// Details about echo files
const
  RDB_RIEGL_ECHO_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.echo_info';
    Title       : 'Echo Information';
    Description : 'Details about echo files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Echo Information","type":"object","$schema":"http://json-sch'
      + 'ema.org/draft-04/schema#","required":["echo_file"],"properties":{"echo'
      + '_file":{"type":"object","properties":{"file_uuid":{"description":"File'
      + '''s Universally Unique Identifier (RFC '
      + '4122)","type":"string"},"file_extension":{"description":"Echo file '
      + 'extension, without the leading dot","type":"string"}},"required":["fil'
      + 'e_extension"]}},"description":"Details about echo files"}'
    );

    Example : (''
      + '{"echo_file":{"file_uuid":"26a03615-67c0-4bea-8fe8-c577378fe661","file'
      + '_extension":"owp"}}'
    );
  );

// Details for exponential decomposition of full waveform data
const
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.exponential_decomposition';
    Title       : 'Exponential Decomposition';
    Description : 'Details for exponential decomposition of full waveform data';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"patternProperties":{"^[0-9]+$":{"description":"one field per '
      + 'channel, field name is channel '
      + 'index","$ref":"#/definitions/channel"}},"title":"Exponential Decomposi'
      + 'tion","additionalProperties":false,"type":"object","$schema":"http://j'
      + 'son-schema.org/draft-04/schema#","definitions":{"channel":{"type":"obj'
      + 'ect","properties":{"delay":{"description":"delay calibration in '
      + 'seconds","type":"number"},"parameter":{"description":"parameters of '
      + 'the syswave exponential sum","required":["A","B","gamma","omega"],"pro'
      + 'perties":{"omega":{"description":"angular frequency in '
      + 'Hz","items":{"type":"number"},"type":"array"},"A":{"description":"real'
      + ' part of amplitude factor in units of full-scale","items":{"type":"num'
      + 'ber"},"type":"array"},"B":{"description":"imaginary part of amplitude '
      + 'factor in units of full-scale","items":{"type":"number"},"type":"array'
      + '"},"gamma":{"description":"decay in 1/second","items":{"type":"number"'
      + '},"type":"array"}},"type":"object"},"scale":{"description":"amplitude '
      + 'calibration","type":"number"},"a_lin":{"minimum":0,"description":"rela'
      + 'tive linear amplitude range [0..1]","type":"number","exclusiveMinimum"'
      + ':false,"exclusiveMaximum":false,"maximum":1}},"required":["delay","sca'
      + 'le","parameter"]}},"description":"Details for exponential '
      + 'decomposition of full waveform data"}'
    );

    Example : (''
      + '{"0":{"delay":3.783458418887631e-09,"parameter":{"omega":[352020896.0,'
      + '3647927552.0,-1977987072.0],"A":[0.9772450923919678,0.3354335129261017'
      + ',-1.312678575515747],"B":[-3.9813032150268555,0.08622030913829803,-0.3'
      + '152860999107361],"gamma":[-1094726528.0,-769562752.0,-848000064.0]},"s'
      + 'cale":1.0,"a_lin":0.27},"1":{"delay":3.5e-09,"parameter":{"omega":[352'
      + '020896.0,3647927552.0,-1977987072.0],"A":[0.9,0.3,-1.3],"B":[-3.9,0.0,'
      + '-0.3],"gamma":[-1094726528.0,-769562752.0,-848000064.0]},"scale":1.0,"'
      + 'a_lin":0.9}}'
    );
  );

// Details for Gaussian decomposition of full waveform data
const
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.gaussian_decomposition';
    Title       : 'Gaussian Decomposition';
    Description : 'Details for Gaussian decomposition of full waveform data';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Gaussian Decomposition","type":"object","$schema":"http://js'
      + 'on-schema.org/draft-04/schema#","required":["amplitude_lsb_low_power",'
      + '"amplitude_lsb_high_power","amplitude_db","range_offset_sec_low_power"'
      + ',"range_offset_sec_high_power"],"properties":{"range_offset_sec_high_p'
      + 'ower":{"type":"array","items":{"type":"number"}},"amplitude_db":{"type'
      + '":"array","items":{"type":"number"}},"range_offset_sec_low_power":{"ty'
      + 'pe":"array","items":{"type":"number"}},"amplitude_lsb_high_power":{"ty'
      + 'pe":"array","items":{"type":"number"}},"amplitude_lsb_low_power":{"typ'
      + 'e":"array","items":{"type":"number"}}},"description":"riegl.gaussian_d'
      + 'ecomposition contains information relevant for extracting calibrated '
      + 'amplitudes and calibrated ranges from a Gaussian decomposition of full'
      + ' waveform data. This information is contained in a table with five '
      + 'columns. Two columns are to be used as input: amplitude_lsb_low_power '
      + 'and amplitude_lsb_high_power. The other three columns provide the '
      + 'outputs. Amplitude_db gives the calibrated amplitude in the optical '
      + 'regime in decibels. The range offset columns provide additive range '
      + 'offsets, given in units of seconds, for each channel."}'
    );

    Example : (''
      + '{"range_offset_sec_high_power":[],"amplitude_db":[],"range_offset_sec_'
      + 'low_power":[],"amplitude_lsb_high_power":[],"amplitude_lsb_low_power":'
      + '[]}'
    );
  );

// Point cloud georeferencing information
const
  RDB_RIEGL_GEO_TAG : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.geo_tag';
    Title       : 'Geo Tag';
    Description : 'Point cloud georeferencing information';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","title":"Geo Tag"'
      + ',"properties":{"crs":{"type":"object","properties":{"name":{"descripti'
      + 'on":"Coordinate reference system '
      + 'name","type":"string"},"epsg":{"minimum":0,"description":"EPSG '
      + 'code","type":"integer"},"wkt":{"description":"\"Well-Known Text\" '
      + 'string, OGC WKT dialect (see http://www.opengeospatial.org/standards/w'
      + 'kt-crs)","type":"string"}},"description":"Global Coordinate Reference '
      + 'System. Please note that only 3D Cartesian Coordinate Systems are allo'
      + 'wed."},"pose":{"type":"array","minItems":4,"items":{"description":"row'
      + 's","minItems":4,"items":{"description":"columns","type":"number"},"max'
      + 'Items":4,"type":"array"},"maxItems":4,"description":"Coordinate '
      + 'Transformation Matrix to transform from File Coordinate System to '
      + 'Global Coordinate Reference System. 4x4 matrix stored as two '
      + 'dimensional array, row major '
      + 'order."}},"type":"object","description":"Point cloud georeferencing '
      + 'information"}'
    );

    Example : (''
      + '{"crs":{"name":"WGS84 Geocentric","epsg":4978,"wkt":"GEOCCS[\"WGS84 Ge'
      + 'ocentric\",DATUM[\"WGS84\",SPHEROID[\"WGS84\",6378137.000,298.25722356'
      + '3,AUTHORITY[\"EPSG\",\"7030\"]],AUTHORITY[\"EPSG\",\"6326\"]],PRIMEM[\'
      + '"Greenwich\",0.0000000000000000,AUTHORITY[\"EPSG\",\"8901\"]],UNIT[\"M'
      + 'eter\",1.00000000000000000000,AUTHORITY[\"EPSG\",\"9001\"]],AXIS[\"X\"'
      + ',OTHER],AXIS[\"Y\",EAST],AXIS[\"Z\",NORTH],AUTHORITY[\"EPSG\",\"4978\"'
      + ']]"},"pose":[[-0.269827776749716,-0.723017716139738,0.635954678449952,'
      + '4063882.500831],[0.962908599449764,-0.20260517250352,0.178208229833847'
      + ',1138787.607461],[0.0,0.660451759194338,0.7508684796801,4766084.550196'
      + '],[0.0,0.0,0.0,1.0]]}'
    );
  );

// Geometric scale factor applied to point coordinates
const
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.geometric_scale_factor';
    Title       : 'Geometric Scale Factor';
    Description : 'Geometric scale factor applied to point coordinates';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","description":"Ge'
      + 'ometric scale factor applied to point '
      + 'coordinates","exclusiveMinimum":true,"minimum":0,"type":"number"}'
    );

    Example : (''
      + '1.0'
    );
  );

// Parameters used for georeferencing of the point cloud
const
  RDB_RIEGL_GEOREFERENCING_PARAMETERS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.georeferencing_parameters';
    Title       : 'Georeferencing Parameters';
    Description : 'Parameters used for georeferencing of the point cloud';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","title":"Georefer'
      + 'encing Parameters","properties":{"socs_to_body_matrix":{"type":"array"'
      + ',"minItems":4,"items":{"description":"rows","minItems":4,"items":{"des'
      + 'cription":"columns","type":"number"},"maxItems":4,"type":"array"},"max'
      + 'Items":4,"description":"Coordinate Transformation Matrix to transform '
      + 'from Scanner''s Own Coordinate System to Body Coordinate System. 4x4 '
      + 'matrix stored as two dimensional array, row major order."},"trajectory'
      + '_file":{"type":"object","required":["file_extension"],"properties":{"f'
      + 'ile_uuid":{"description":"File''s Universally Unique Identifier (RFC '
      + '4122)","type":"string"},"file_extension":{"description":"Trajectory '
      + 'file extension, without the leading '
      + 'dot","type":"string"}},"description":"Trajectory data used for '
      + 'georeferencing of the point cloud"},"body_coordinate_system_type":{"ty'
      + 'pe":"string","enum":["NED","ENU"],"description":"BODY coordinate frame'
      + ' (NED: North-East-Down, ENU: East-North-Up), default: NED"},"trajector'
      + 'y_offsets":{"type":"object","properties":{"offset_height":{"type":"num'
      + 'ber","description":"[m]"},"offset_roll":{"type":"number","description"'
      + ':"[deg]"},"offset_north":{"type":"number","description":"[m]"},"offset'
      + '_pitch":{"type":"number","description":"[deg]"},"offset_time":{"type":'
      + '"number","description":"[s]"},"offset_yaw":{"type":"number","descripti'
      + 'on":"[deg]"},"offset_east":{"type":"number","description":"[m]"},"vers'
      + 'ion":{"type":"integer","description":"Meaning of offset values and how'
      + ' to apply them; version 0: '
      + 'Rz(yaw+offset_yaw)*Ry(pitch+offset_pitch)*Rx(roll+offset_roll), '
      + 'version 1: Rz(yaw)*Ry(pitch)*Rx(roll) * Rz(offset_yaw)*Ry(offset_pitch'
      + ')*Rx(offset_roll)"}},"description":"Correction offsets applied to the '
      + 'trajectory data"},"socs_to_rocs_matrix":{"type":"array","minItems":4,"'
      + 'items":{"description":"rows","minItems":4,"items":{"description":"colu'
      + 'mns","type":"number"},"maxItems":4,"type":"array"},"maxItems":4,"descr'
      + 'iption":"Coordinate Transformation Matrix to transform from Scanner''s '
      + 'Own Coordinate System to Record Coordinate System. 4x4 matrix stored '
      + 'as two dimensional array, row major '
      + 'order."}},"type":"object","description":"Parameters used for '
      + 'georeferencing of the point cloud"}'
    );

    Example : (''
      + '{"socs_to_body_matrix":[[-0.269827776749716,-0.723017716139738,0.63595'
      + '4678449952,0.0],[0.962908599449764,-0.20260517250352,0.178208229833847'
      + ',0.0],[0.0,0.660451759194338,0.7508684796801,0.0],[0.0,0.0,0.0,1.0]],"'
      + 'trajectory_file":{"file_uuid":"93a03615-66c0-4bea-8ff8-c577378fe660","'
      + 'file_extension":"pofx"},"body_coordinate_system_type":"NED","trajector'
      + 'y_offsets":{"offset_height":-0.2,"offset_roll":0.03,"offset_north":0.0'
      + '7,"offset_pitch":0.01,"offset_time":18.007,"offset_yaw":-0.45,"offset_'
      + 'east":0.15,"version":0}}'
    );
  );

// Map of item names
const
  RDB_RIEGL_ITEM_NAMES : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.item_names';
    Title       : 'Item Names';
    Description : 'Map of item names';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"patternProperties":{"^-?[0-9]+$":{"description":"One field per item,'
      + ' field name is item id, field value is item '
      + 'name","type":"string"}},"title":"Item Names","type":"object","$schema"'
      + ':"http://json-schema.org/draft-04/schema#","additionalProperties":fals'
      + 'e,"description":"Map of item names"}'
    );

    Example : (''
      + '{"2":"Name of item with id 2","47":"Name of item with id 47","1":"Name'
      + ' of item with id 1","-1":"Name of item with id -1"}'
    );
  );

// License keys for software features
const
  RDB_RIEGL_LICENSES : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.licenses';
    Title       : 'Software License Keys';
    Description : 'License keys for software features';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"patternProperties":{"^.*$":{"description":"Each field of the object '
      + 'represents a feature and holds a list of license keys, where the field'
      + ' name is the feature '
      + 'name.","minItems":1,"items":{"description":"License key (example: '
      + '''46AE032A - 39882AC4 - 9EC0A184 - '
      + '6F163D73'')","type":"string"},"type":"array"}},"title":"Software '
      + 'License Keys","type":"object","$schema":"http://json-schema.org/draft-'
      + '04/schema#","additionalProperties":false,"description":"License keys '
      + 'for software features"}'
    );

    Example : (''
      + '{"Full Waveform Analysis Topography with GPU support":["8AB44126 - '
      + '23B92250 - 16E2689F - 34EF7E7B"],"Full Waveform Analysis '
      + 'Topography":["0FD5FF07 - 011A1255 - 9F76CACA - 8D2ED557"],"MTA '
      + 'resolution":["468E020A - 39A922E4 - B681A184 - '
      + '673E3D72"],"Georeferencing":["46AE032A - 39882AC4 - 9EC0A184 - '
      + '6F163D73"]}'
    );
  );

// Parameters for MTA processing
const
  RDB_RIEGL_MTA_SETTINGS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.mta_settings';
    Title       : 'MTA Settings';
    Description : 'Parameters for MTA processing';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","title":"MTA Sett'
      + 'ings","properties":{"modulation_depth":{"minimum":0,"type":"number","d'
      + 'escription":"Depth of pulse position modulation in meter."},"zone_coun'
      + 't":{"minimum":0,"type":"integer","maximum":255,"description":"Maximum '
      + 'number of MTA zones."},"zone_width":{"minimum":0,"type":"number","desc'
      + 'ription":"Width of a MTA zone in '
      + 'meter."}},"type":"object","description":"Parameters for MTA '
      + 'processing"}'
    );

    Example : (''
      + '{"modulation_depth":9.368514,"zone_count":23,"zone_width":149.896225}'
    );
  );

// Lookup table for range correction based on raw range
const
  RDB_RIEGL_NEAR_RANGE_CORRECTION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.near_range_correction';
    Title       : 'Near Range Correction Table';
    Description : 'Lookup table for range correction based on raw range';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Near Range Correction Table","type":"object","$schema":"http'
      + '://json-schema.org/draft-04/schema#","required":["delta","content"],"p'
      + 'roperties":{"delta":{"description":"Delta between table entries [m], '
      + 'first entry is at range = 0 '
      + 'm","type":"number"},"content":{"description":"Correction value [m] to '
      + 'be added to the raw range","minItems":1,"items":{"type":"number"},"max'
      + 'Items":2000,"type":"array"}},"description":"Lookup table for range '
      + 'correction based on raw range"}'
    );

    Example : (''
      + '{"delta":0.512,"content":[0.0]}'
    );
  );

// Standard deviation for range and amplitude as a function of amplitude
const
  RDB_RIEGL_NOISE_ESTIMATES : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.noise_estimates';
    Title       : 'Noise Estimates';
    Description : 'Standard deviation for range and amplitude as a function of amplitude';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Noise Estimates","type":"object","$schema":"http://json-sche'
      + 'ma.org/draft-04/schema#","required":["amplitude","range_sigma","amplit'
      + 'ude_sigma"],"properties":{"amplitude":{"type":"array","items":{"type":'
      + '"number"},"description":"Amplitude [dB]"},"range_sigma":{"type":"array'
      + '","items":{"type":"number"},"description":"Sigma range [m]"},"amplitud'
      + 'e_sigma":{"type":"array","items":{"type":"number"},"description":"Sigm'
      + 'a amplitude [dB]"}},"description":"Standard deviation for range and '
      + 'amplitude as a function of amplitude"}'
    );

    Example : (''
      + '{"amplitude":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0],"range_sig'
      + 'ma":[0.065,0.056,0.046,0.038,0.032,0.027,0.024,0.021,0.018,0.016,0.014'
      + '],"amplitude_sigma":[0.988,0.988,0.875,0.774,0.686,0.608,0.54,0.482,0.'
      + '432,0.39,0.354]}'
    );
  );

// Notch filter parameters for window glass echoes
const
  RDB_RIEGL_NOTCH_FILTER : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.notch_filter';
    Title       : 'Notch Filter';
    Description : 'Notch filter parameters for window glass echoes';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Notch Filter","type":"object","$schema":"http://json-schema.'
      + 'org/draft-04/schema#","required":["range_minimum","range_maximum","amp'
      + 'litude_maximum"],"properties":{"range_minimum":{"type":"number","descr'
      + 'iption":"Minimum range '
      + '[m]"},"range_maximum":{"type":"number","description":"Maximum range [m'
      + ']"},"amplitude_maximum":{"minimum":0,"type":"number","description":"Ma'
      + 'ximum amplitude [dB]"}},"description":"Notch filter parameters for '
      + 'window glass echoes"}'
    );

    Example : (''
      + '{"range_minimum":-0.5,"range_maximum":0.2,"amplitude_maximum":18.0}'
    );
  );

// Details about the pixels contained in the file
const
  RDB_RIEGL_PIXEL_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pixel_info';
    Title       : 'Pixel Information';
    Description : 'Details about the pixels contained in the file';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Pixel Information","required":["size"],"type":"object","$sch'
      + 'ema":"http://json-schema.org/draft-04/schema#","definitions":{"pixel_s'
      + 'ize":{"type":"array","minItems":2,"items":{"minimum":0,"type":"number"'
      + ',"description":"Length of pixel edge '
      + '[m]."},"maxItems":2,"description":"Size of '
      + 'pixels."}},"properties":{"size":{"description":"Size of pixels in file'
      + ' coordinate system.","$ref":"#/definitions/pixel_size"},"size_llcs":{"'
      + 'description":"Size of pixels in a locally levelled cartesian '
      + 'coordinate system (xy). This is only used for pixels based on a map pr'
      + 'ojection.","$ref":"#/definitions/pixel_size"}},"description":"Details '
      + 'about the pixels contained in the file"}'
    );

    Example : (''
      + '{"size":[0.5971642834779395,0.5971642834779395],"size_llcs":[0.5156575'
      + '252891171,0.5130835356683303]}'
    );
  );

// Details about the plane patch matching process
const
  RDB_RIEGL_PLANE_PATCH_MATCHING : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.plane_patch_matching';
    Title       : 'Plane Patch Matching';
    Description : 'Details about the plane patch matching process';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Plane Patch Matching","required":["plane_patch_file_one","pl'
      + 'ane_patch_file_two"],"type":"object","$schema":"http://json-schema.org'
      + '/draft-04/schema#","definitions":{"file_reference":{"type":"object","r'
      + 'equired":["file_uuid","file_path"],"properties":{"file_path":{"descrip'
      + 'tion":"Path of the plane patch file relative to the match '
      + 'file","type":"string"},"file_uuid":{"description":"Plane patch file''s '
      + 'Universally Unique Identifier (RFC '
      + '4122)","type":"string"}},"description":"Reference to a plane patch '
      + 'file"}},"properties":{"plane_patch_file_two":{"description":"Reference'
      + ' to the plane patch file two","$ref":"#/definitions/file_reference"},"'
      + 'plane_patch_file_one":{"description":"Reference to the plane patch '
      + 'file '
      + 'one","$ref":"#/definitions/file_reference"}},"description":"Details '
      + 'about the plane patch matching process"}'
    );

    Example : (''
      + '{"plane_patch_file_two":{"file_path":"project.ptch","file_uuid":"fa47d'
      + '509-a64e-49ce-8b14-ff3130fbefa9"},"plane_patch_file_one":{"file_path":'
      + '"Record009_Line001/191025_121410_Scanner_1.ptch","file_uuid":"810f5d57'
      + '-eccf-49ed-b07a-0cdd109b4213"}}'
    );
  );

// Statistics about plane patches found by plane patch extractor
const
  RDB_RIEGL_PLANE_PATCH_STATISTICS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.plane_patch_statistics';
    Title       : 'Plane Patch Statistics';
    Description : 'Statistics about plane patches found by plane patch extractor';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","title":"Plane '
      + 'Patch Statistics","properties":{"total_area":{"type":"number","descrip'
      + 'tion":"sum of all plane patch areas [m\u00b2]"},"total_horizontal_area'
      + '":{"type":"number","description":"sum of all plane patch areas '
      + 'projected to horizontal plane '
      + '[m\u00b2]"}},"type":"object","description":"Statistics about plane '
      + 'patches found by plane patch extractor"}'
    );

    Example : (''
      + '{"total_area":14007.965,"total_horizontal_area":13954.601}'
    );
  );

// Settings and classes for plane slope classification
const
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.plane_slope_class_info';
    Title       : 'Plane Slope Class Info';
    Description : 'Settings and classes for plane slope classification';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Plane Slope Class Info","required":["settings","classes"],"t'
      + 'ype":"object","$schema":"http://json-schema.org/draft-04/schema#","def'
      + 'initions":{"method-2":{"type":"object","required":["plane_classificati'
      + 'on_method","sloping_plane_classes_minimum_angle","sloping_plane_classe'
      + 's_maximum_angle"],"properties":{"sloping_plane_classes_maximum_angle":'
      + '{"minimum":-360.0,"type":"number","maximum":360.0,"description":"maxim'
      + 'um inclination angle of sloping plane patches [deg]"},"plane_classific'
      + 'ation_method":{"minimum":2,"type":"integer","maximum":2,"description":'
      + '"method ID (=2)"},"sloping_plane_classes_minimum_angle":{"minimum":-36'
      + '0.0,"type":"number","maximum":360.0,"description":"minimum inclination'
      + ' angle of sloping plane patches [deg]"}},"description":"Classification'
      + ' method 2"},"method-1":{"type":"object","required":["plane_classificat'
      + 'ion_method","maximum_inclination_angle_horizontal"],"properties":{"max'
      + 'imum_inclination_angle_horizontal":{"minimum":-360.0,"type":"number","'
      + 'maximum":360.0,"description":"maximum inclination angle of horizontal '
      + 'plane patches [deg]"},"plane_classification_method":{"minimum":1,"type'
      + '":"integer","maximum":1,"description":"method ID '
      + '(=1)"}},"description":"Classification method 1"}},"properties":{"setti'
      + 'ngs":{"type":"object","oneOf":[{"$ref":"#/definitions/method-1"},{"$re'
      + 'f":"#/definitions/method-2"}],"description":"Classification settings, '
      + 'details see documentation of rdbplanes"},"classes":{"patternProperties'
      + '":{"^[0-9]+$":{"description":"one field per class, field name is class'
      + ' number, field value is class name","type":"string"}},"type":"object",'
      + '"additionalProperties":false,"description":"Class definition '
      + 'table"}},"description":"Settings and classes for plane slope '
      + 'classification"}'
    );

    Example : (''
      + '{"settings":{"sloping_plane_classes_maximum_angle":70.0,"plane_classif'
      + 'ication_method":2,"sloping_plane_classes_minimum_angle":10.0},"classes'
      + '":{"3":"sloping, pointing up and south","11":"sloping, pointing down '
      + 'and south","10":"sloping, pointing down and east","5":"sloping, '
      + 'pointing up and west","2":"sloping, pointing up and '
      + 'east","6":"vertical, pointing east","12":"sloping, pointing down and '
      + 'north","8":"vertical, pointing north","7":"vertical, pointing '
      + 'south","4":"sloping, pointing up and north","13":"sloping, pointing '
      + 'down and west","9":"vertical, pointing west","1":"horizontal, pointing'
      + ' up","14":"horizontal, pointing down"}}'
    );
  );

// Grouping and sorting of point attributes for visualization purposes
const
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.point_attribute_groups';
    Title       : 'Point Attribute Groups';
    Description : 'Grouping and sorting of point attributes for visualization purposes';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"patternProperties":{"^.*$":{"description":"Each field of the object '
      + 'represents a point attribute group and holds a list of point '
      + 'attributes, where the field name is the group '
      + 'name.","minItems":1,"items":{"description":"Point attribute full name '
      + 'or name pattern (perl regular expression '
      + 'syntax)","type":"string"},"type":"array"}},"title":"Point Attribute Gr'
      + 'oups","type":"object","$schema":"http://json-schema.org/draft-04/schem'
      + 'a#","additionalProperties":false,"description":"Grouping and sorting '
      + 'of point attributes for visualization purposes"}'
    );

    Example : (''
      + '{"Primary Attributes":["riegl.reflectance","riegl.amplitude","riegl.de'
      + 'viation"],"Time":["riegl.timestamp"],"Other '
      + 'Attributes":["riegl.selected","riegl.visible"],"Secondary Attributes":'
      + '["riegl.mirror_facet","riegl.waveform_available"],"Coordinates/Vectors'
      + '":["riegl.xyz","riegl.range","riegl.theta","riegl.phi"]}'
    );
  );

// Details about point cloud files
const
  RDB_RIEGL_POINTCLOUD_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pointcloud_info';
    Title       : 'Point Cloud Information';
    Description : 'Details about point cloud files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","title":"Point '
      + 'Cloud Information","properties":{"comments":{"description":"Comments",'
      + '"type":"string"},"project":{"description":"Project '
      + 'name","type":"string"},"field_of_application":{"description":"Field of'
      + ' application","enum":["unknown","SLS","TLS","KLS","MLS","ULS","ALS","B'
      + 'LS","ILS"],"type":"string"}},"type":"object","description":"Details '
      + 'about point cloud files"}'
    );

    Example : (''
      + '{"comments":"Line 3","project":"Campaign '
      + '4","field_of_application":"ALS"}'
    );
  );

// Estimated position and orientation information
const
  RDB_RIEGL_POSE_ESTIMATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pose_estimation';
    Title       : 'Pose Estimation';
    Description : 'Estimated position and orientation information';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Pose Estimation","type":"object","$schema":"http://json-sche'
      + 'ma.org/draft-04/schema#","required":["orientation"],"properties":{"bar'
      + 'ometric_height_amsl":{"description":"Altitude determined based on the '
      + 'atmospheric pressure according to the standard atmosphere laws '
      + '[m].","type":"number"},"position":{"description":"Position coordinates'
      + ' and position accuracy values as measured by GNSS in the specified '
      + 'Coordinate Reference System (CRS)","required":["coordinate_1","coordin'
      + 'ate_2","coordinate_3","horizontal_accuracy","vertical_accuracy","crs"]'
      + ',"properties":{"crs":{"type":"object","required":["epsg"],"properties"'
      + ':{"epsg":{"minimum":0,"description":"EPSG '
      + 'code","type":"integer"},"wkt":{"description":"\"Well-Known Text\" '
      + 'string, OGC WKT dialect (see http://www.opengeospatial.org/standards/w'
      + 'kt-crs)","type":"string"}},"description":"Global Coordinate Reference '
      + 'System"},"vertical_accuracy":{"minimum":0,"description":"Vertical '
      + 'accuracy [m]","exclusiveMinimum":true,"type":"number"},"horizontal_acc'
      + 'uracy":{"minimum":0,"description":"Horizontal accuracy [m]","exclusive'
      + 'Minimum":true,"type":"number"},"coordinate_3":{"description":"Coordina'
      + 'te 3 as defined by axis 3 of the specified CRS (e.g., Z, '
      + 'Altitude)","type":"number"},"coordinate_1":{"description":"Coordinate '
      + '1 as defined by axis 1 of the specified CRS (e.g., X, '
      + 'Latitude)","type":"number"},"coordinate_2":{"description":"Coordinate '
      + '2 as defined by axis 2 of the specified CRS (e.g., Y, Longitude)","typ'
      + 'e":"number"}},"type":"object"},"orientation":{"description":"Orientati'
      + 'on values and orientation accuracies, measured with IMU or inclination'
      + ' sensors.","required":["roll","pitch","yaw","roll_accuracy","pitch_acc'
      + 'uracy","yaw_accuracy"],"properties":{"roll_accuracy":{"minimum":0,"des'
      + 'cription":"Roll angle accuracy [deg]","exclusiveMinimum":true,"type":"'
      + 'number"},"yaw":{"minimum":-360,"description":"Yaw angle about scanner '
      + 'Z-axis [deg]","maximum":360,"type":"number"},"pitch":{"minimum":-360,"'
      + 'description":"Pitch angle about scanner Y-axis [deg]","maximum":360,"t'
      + 'ype":"number"},"pitch_accuracy":{"minimum":0,"description":"Pitch '
      + 'angle accuracy [deg]","exclusiveMinimum":true,"type":"number"},"yaw_ac'
      + 'curacy":{"minimum":0,"description":"Yaw angle accuracy [deg]","exclusi'
      + 'veMinimum":true,"type":"number"},"roll":{"minimum":-360,"description":'
      + '"Roll angle about scanner X-axis [deg]","maximum":360,"type":"number"}'
      + '},"type":"object"}},"description":"Estimated position and orientation '
      + 'information as measured by GNSS, IMU or inclination sensors"}'
    );

    Example : (''
      + '{"barometric_height_amsl":386.7457796227932,"position":{"crs":{"epsg":'
      + '4979,"wkt":"GEOGCS[\"WGS84 / Geographic\",DATUM[\"WGS84\",SPHEROID[\"W'
      + 'GS84\",6378137.000,298.257223563,AUTHORITY[\"EPSG\",\"7030\"]],AUTHORI'
      + 'TY[\"EPSG\",\"6326\"]],PRIMEM[\"Greenwich\",0.0000000000000000,AUTHORI'
      + 'TY[\"EPSG\",\"8901\"]],UNIT[\"Degree\",0.01745329251994329547,AUTHORIT'
      + 'Y[\"EPSG\",\"9102\"]],AXIS[\"Latitude\",NORTH],AXIS[\"Longitude\",EAST'
      + '],AUTHORITY[\"EPSG\",\"4979\"]]"},"vertical_accuracy":1.33149993419647'
      + '22,"horizontal_accuracy":0.810699999332428,"coordinate_3":362.71249389'
      + '64844,"coordinate_1":48.655799473,"coordinate_2":15.645033406},"orient'
      + 'ation":{"roll_accuracy":0.009433783936875745,"yaw":101.87293630292045,'
      + '"pitch":1.509153024827064,"pitch_accuracy":0.009433783936875745,"yaw_a'
      + 'ccuracy":1.0094337839368757,"roll":3.14743073066123}}'
    );
  );

// Details on position and orientation sensors
const
  RDB_RIEGL_POSE_SENSORS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pose_sensors';
    Title       : 'Pose Sensors';
    Description : 'Details on position and orientation sensors';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Pose Sensors","required":["gyroscope","accelerometer","magne'
      + 'tic_field_sensor"],"type":"object","$schema":"http://json-schema.org/d'
      + 'raft-04/schema#","definitions":{"vector":{"type":"array","minItems":3,'
      + '"maxItems":3,"items":{"type":"number","description":"Index 0=X, 1=Y, '
      + '2=Z component"}}},"properties":{"magnetic_field_sensor":{"type":"objec'
      + 't","required":["unit","x_axis","y_axis","z_axis","offset","fixed","rel'
      + 'ative_nonlinearity"],"properties":{"fixed":{"description":"Distortion '
      + 'of magnetic field caused by non-rotating scanner part","$ref":"#/defin'
      + 'itions/vector"},"relative_nonlinearity":{"description":"Relative '
      + 'nonlinearity, dimensionless","$ref":"#/definitions/vector"},"z_axis":{'
      + '"description":"Sensitive Z axis of sensor at frame angle = 0","$ref":"'
      + '#/definitions/vector"},"unit":{"minimum":0,"type":"number","exclusiveM'
      + 'inimum":true,"description":"Unit of raw data and calibration values, 1'
      + ' LSB in nT"},"offset":{"description":"Value to be subtracted from raw '
      + 'measurement values","$ref":"#/definitions/vector"},"y_axis":{"descript'
      + 'ion":"Sensitive Y axis of sensor at frame angle = '
      + '0","$ref":"#/definitions/vector"},"x_axis":{"description":"Sensitive X'
      + ' axis of sensor at frame angle = '
      + '0","$ref":"#/definitions/vector"}},"description":"Magnetic Field '
      + 'Sensor details"},"gyroscope":{"type":"object","required":["unit","x_ax'
      + 'is","y_axis","z_axis","offset","origin","relative_nonlinearity"],"prop'
      + 'erties":{"relative_nonlinearity":{"description":"Relative '
      + 'nonlinearity, dimensionless","$ref":"#/definitions/vector"},"z_axis":{'
      + '"description":"Sensitive Z axis of sensor at frame angle = 0","$ref":"'
      + '#/definitions/vector"},"unit":{"minimum":0,"type":"number","exclusiveM'
      + 'inimum":true,"description":"Unit of raw data and calibration values, 1'
      + ' LSB in rad/s"},"origin":{"description":"Sensor origin in SOCS [m] at '
      + 'frame angle = '
      + '0","$ref":"#/definitions/vector"},"offset":{"description":"Value to be'
      + ' subtracted from raw measurement values","$ref":"#/definitions/vector"'
      + '},"y_axis":{"description":"Sensitive Y axis of sensor at frame angle ='
      + ' 0","$ref":"#/definitions/vector"},"x_axis":{"description":"Sensitive '
      + 'X axis of sensor at frame angle = '
      + '0","$ref":"#/definitions/vector"}},"description":"Gyroscope details"},'
      + '"accelerometer":{"type":"object","required":["unit","x_axis","y_axis",'
      + '"z_axis","offset","origin","relative_nonlinearity"],"properties":{"rel'
      + 'ative_nonlinearity":{"description":"Relative nonlinearity, dimensionle'
      + 'ss","$ref":"#/definitions/vector"},"z_axis":{"description":"Sensitive '
      + 'Z axis of sensor at frame angle = 0","$ref":"#/definitions/vector"},"u'
      + 'nit":{"minimum":0,"type":"number","exclusiveMinimum":true,"description'
      + '":"Unit of raw data and calibration values, 1 LSB in 9.81 '
      + 'm/s\u00b2"},"origin":{"description":"Sensor origin in SOCS [m] at '
      + 'frame angle = '
      + '0","$ref":"#/definitions/vector"},"offset":{"description":"Value to be'
      + ' subtracted from raw measurement values","$ref":"#/definitions/vector"'
      + '},"y_axis":{"description":"Sensitive Y axis of sensor at frame angle ='
      + ' 0","$ref":"#/definitions/vector"},"x_axis":{"description":"Sensitive '
      + 'X axis of sensor at frame angle = '
      + '0","$ref":"#/definitions/vector"}},"description":"Accelerometer '
      + 'details"}},"description":"Details on position and orientation '
      + 'sensors"}'
    );

    Example : (''
      + '{"magnetic_field_sensor":{"fixed":[-1576.010498046875,1596.08178710937'
      + '5,0.0],"relative_nonlinearity":[0.0,0.0,0.0],"z_axis":[0.0004198786627'
      + '9669106,7.876977906562388e-05,0.011407104320824146],"unit":91.74311828'
      + '613281,"offset":[-23812.052734375,5606.57666015625,2493.28125],"y_axis'
      + '":[0.00027888521435670555,-0.011427424848079681,-5.204829722060822e-05'
      + '],"x_axis":[-0.011162743903696537,-2.315962774446234e-05,0.00016818844'
      + '596855342]},"gyroscope":{"relative_nonlinearity":[2.888176311444113e-0'
      + '7,1.06274164579645e-07,-1.7186295080634935e-39],"z_axis":[0.5558699965'
      + '47699,119.22135162353516,0.467585027217865],"unit":0.00014544410805683'
      + '583,"origin":[0.026900000870227814,-0.03999999910593033,-0.08950000256'
      + '299973],"offset":[-50.92609786987305,146.15643310546875,62.43272781372'
      + '07],"y_axis":[-0.440765917301178,-0.7897399663925171,119.5894775390625'
      + '],"x_axis":[-121.195556640625,0.8219714164733887,0.2313031703233719]},'
      + '"accelerometer":{"relative_nonlinearity":[0.0,0.0,0.0],"z_axis":[1.639'
      + '882206916809,15166.744140625,-116.99742889404297],"unit":6.66666674078'
      + '4422e-05,"origin":[0.026900000870227814,-0.03999999910593033,-0.089500'
      + '00256299973],"offset":[-733.3636474609375,58.969032287597656,1060.2550'
      + '048828125],"y_axis":[-7.027288913726807,-44.12333679199219,14952.37011'
      + '71875],"x_axis":[-15008.123046875,56.956390380859375,-60.5175666809082'
      + ']}}'
    );
  );

// Laser pulse position modulation used for MTA resolution
const
  RDB_RIEGL_PULSE_POSITION_MODULATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pulse_position_modulation';
    Title       : 'Pulse Position Modulation';
    Description : 'Laser pulse position modulation used for MTA resolution';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Pulse Position Modulation","type":"object","$schema":"http:/'
      + '/json-schema.org/draft-04/schema#","required":["length","num_mod_ampl"'
      + ',"pulse_interval"],"properties":{"num_mod_ampl":{"minimum":0,"type":"i'
      + 'nteger","maximum":255,"description":"Number of different modulation '
      + 'amplitudes (2: binary modulation)"},"code_phase_mode":{"minimum":0,"ty'
      + 'pe":"integer","maximum":255,"description":"0: no synchronization, 1: '
      + 'toggle between 2 phases, 2: increment with phase_increment"},"phase_st'
      + 'ep":{"minimum":0,"type":"integer","maximum":255,"description":"Step '
      + 'width in phase of modulation code from line to line"},"pulse_interval"'
      + ':{"type":"array","items":{"minimum":0,"type":"number"},"description":"'
      + 'Explicit table of the pulse position modulation used for MTA '
      + 'resolution. Table gives times between successive laser pulses in secon'
      + 'ds."},"length":{"minimum":0,"type":"integer","maximum":255,"descriptio'
      + 'n":"Length of code"}},"description":"Laser pulse position modulation '
      + 'used for MTA resolution"}'
    );

    Example : (''
      + '{"num_mod_ampl":2,"code_phase_mode":2,"phase_step":5,"pulse_interval":'
      + '[2.759375e-06,2.759375e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.75'
      + '9375e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.821875e-06,2.821875e'
      + '-06,2.759375e-06,2.759375e-06,2.821875e-06,2.821875e-06,2.821875e-06,2'
      + '.821875e-06,2.821875e-06,2.759375e-06,2.759375e-06,2.759375e-06,2.8218'
      + '75e-06,2.821875e-06,2.759375e-06,2.821875e-06,2.821875e-06,2.821875e-0'
      + '6,2.759375e-06,2.821875e-06,2.759375e-06,2.821875e-06],"length":31}'
    );
  );

// Statistics about target distance wrt. SOCS origin
const
  RDB_RIEGL_RANGE_STATISTICS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.range_statistics';
    Title       : 'Range Statistics';
    Description : 'Statistics about target distance wrt. SOCS origin';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Range Statistics","type":"object","$schema":"http://json-sch'
      + 'ema.org/draft-04/schema#","required":["minimum","average","maximum","s'
      + 'td_dev"],"properties":{"minimum":{"type":"number","description":"Minim'
      + 'um value"},"average":{"type":"number","description":"Average '
      + 'value"},"std_dev":{"type":"number","description":"Standard '
      + 'deviation"},"maximum":{"type":"number","description":"Maximum '
      + 'value"}},"description":"Statistics about target distance wrt. SOCS '
      + 'origin"}'
    );

    Example : (''
      + '{"minimum":0.919,"average":15.49738,"std_dev":24.349,"maximum":574.35}'
    );
  );

// Receiver Internals
const
  RDB_RIEGL_RECEIVER_INTERNALS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.receiver_internals';
    Title       : 'Receiver Internals';
    Description : 'Receiver Internals';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Receiver Internals","type":"object","$schema":"http://json-s'
      + 'chema.org/draft-04/schema#","definitions":{"fp_table":{"properties":{"'
      + 'ny":{"type":"integer","max":2048,"description":"number of y entries","'
      + 'min":1},"tc":{"type":"integer","max":255,"description":"table data '
      + 'type '
      + 'code","min":0},"ch":{"type":"integer","max":255,"description":"channel'
      + ' number","min":0},"tv":{"type":"array","minItems":1,"maxItems":2048,"i'
      + 'tems":{"oneOf":[{"$ref":"#/definitions/fp_table_row"},{"type":"number"'
      + '}]}},"nx":{"type":"integer","max":2048,"description":"number of x '
      + 'entries","min":1}},"type":"object","desription":"scanner internal data'
      + '","required":["ch","tc","nx","ny","tv"]},"fp":{"type":"object","requir'
      + 'ed":["s","w"],"properties":{"s":{"type":"array","minItems":1,"maxItems'
      + '":256,"items":{"type":"array","minItems":1,"maxItems":4096,"items":{"t'
      + 'ype":"number"}}},"w":{"type":"array","minItems":1,"maxItems":256,"item'
      + 's":{"type":"array","minItems":5,"maxItems":5,"items":{"type":"number"}'
      + '}}},"description":"Fingerprint values"},"fp_table_row":{"type":"array"'
      + ',"minItems":1,"maxItems":2048,"items":{"type":"number"}}},"properties"'
      + ':{"mw":{"minimum":0,"type":"number","description":"Maximum weight","ma'
      + 'ximum":4095,"exclusiveMinimum":true},"si":{"minimum":0,"type":"number"'
      + ',"maximum":255,"description":"Start index '
      + '(hw_start)"},"a":{"description":"Amplitude [dB]","type":"array","minIt'
      + 'ems":1,"maxItems":256,"items":{"type":"number"}},"ex":{"type":"object"'
      + ',"description":"DEPRECATED, use ''riegl.exponential_decomposition'' inst'
      + 'ead"},"ns":{"minimum":0,"type":"integer","maximum":4095,"description":'
      + '"Number of samples"},"nt":{"minimum":0,"type":"integer","maximum":255,'
      + '"description":"Number of '
      + 'traces"},"tbl":{"type":"array","minItems":1,"description":"various '
      + 'internal data","items":{"$ref":"#/definitions/fp_table"}},"sr":{"minim'
      + 'um":0,"type":"number","description":"Sample rate [Hz]","exclusiveMinim'
      + 'um":true},"t":{"patternProperties":{"^[0-9]+$":{"description":"one '
      + 'field per channel, field name is channel index","$ref":"#/definitions/'
      + 'fp"}},"type":"object","additionalProperties":false}},"description":"Re'
      + 'ceiver Internals"}'
    );

    Example : (''
      + '{"mw":31,"si":48,"a":[-1.55],"ns":400,"nt":128,"tbl":[{"ny":2,"tc":1,"'
      + 'ch":0,"tv":[[1,2,3,4,5],[1.1,2.2,3.3,4.4,5.5]],"nx":5}],"sr":795999700'
      + '0.0,"t":{"0":{"s":[[1.23,4.56],[7.89,0.12]],"w":[[78,86,126,134,31],[7'
      + '8,86,126,134,31]]},"1":{"s":[[1.23,4.56],[7.89,0.12]],"w":[[78,86,126,'
      + '134,31],[78,86,126,134,31]]}}}'
    );
  );

// Lookup table for reflectance calculation based on amplitude and range
const
  RDB_RIEGL_REFLECTANCE_CALCULATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.reflectance_calculation';
    Title       : 'Reflectance Calculation Table';
    Description : 'Lookup table for reflectance calculation based on amplitude and range';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Reflectance Calculation Table","type":"object","$schema":"ht'
      + 'tp://json-schema.org/draft-04/schema#","required":["delta","content"],'
      + '"properties":{"delta":{"description":"Delta between table entries [m],'
      + ' first entry is at range = 0 '
      + 'm","type":"number"},"content":{"description":"Correction value [dB] to'
      + ' be added to the amplitude","minItems":1,"items":{"type":"number"},"ma'
      + 'xItems":2000,"type":"array"}},"description":"Lookup table for '
      + 'reflectance calculation based on amplitude and range"}'
    );

    Example : (''
      + '{"delta":0.150918,"content":[-33.01]}'
    );
  );

// Range-dependent and scan-angle-dependent correction of reflectance reading
const
  RDB_RIEGL_REFLECTANCE_CORRECTION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.reflectance_correction';
    Title       : 'Near-Range Reflectance Correction';
    Description : 'Range-dependent and scan-angle-dependent correction of reflectance reading';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Near-range reflectance correction","type":"object","$schema"'
      + ':"http://json-schema.org/draft-04/schema#","required":["ranges_m","lin'
      + 'e_angles_deg","reflectance_correction_db"],"properties":{"reflectance_'
      + 'correction_db":{"type":"array","items":{"description":"rows (each '
      + 'array corresponds to a range)","items":{"description":"columns (each '
      + 'value corresponds to an '
      + 'angle)","type":"number"},"type":"array"},"description":"Near range '
      + 'reflectance correction in dB as a function of range over angle"},"line'
      + '_angles_deg":{"type":"array","items":{"type":"number"},"description":"'
      + 'Angle [deg]"},"ranges_m":{"type":"array","items":{"type":"number"},"de'
      + 'scription":"Range [m]"}},"description":"Range-dependent and '
      + 'scan-angle-dependent correction of reflectance reading"}'
    );

    Example : (''
      + '{"reflectance_correction_db":[[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.'
      + '01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0'
      + '.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01]],"li'
      + 'ne_angles_deg":[0.0,0.5,1.0,1.5,1.0,2.0,2.5,3.0,3.5,4.0],"ranges_m":[0'
      + '.0,1.0,2.0,3.0]}'
    );
  );

// Scan pattern description
const
  RDB_RIEGL_SCAN_PATTERN : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.scan_pattern';
    Title       : 'Scan Pattern';
    Description : 'Scan pattern description';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","title":"Scan '
      + 'Pattern","definitions":{"program":{"description":"Measurement '
      + 'program","required":["name"],"properties":{"name":{"description":"Name'
      + ' of measurement program","type":"string"},"laser_prr":{"minimum":0,"de'
      + 'scription":"Laser Pulse Repetition Rate [Hz]","exclusiveMinimum":false'
      + ',"type":"number"}},"type":"object"}},"properties":{"line":{"descriptio'
      + 'n":"Line Scan Pattern","required":["start","stop","increment"],"proper'
      + 'ties":{"start":{"minimum":0.0,"description":"Start angle in SOCS [deg]'
      + '","maximum":360.0,"type":"number"},"increment":{"minimum":0.0,"descrip'
      + 'tion":"Increment of angle in SOCS [deg]","maximum":90.0,"type":"number'
      + '"},"stop":{"minimum":0.0,"description":"Stop angle in SOCS [deg]","max'
      + 'imum":720.0,"type":"number"},"program":{"$ref":"#/definitions/program"'
      + '}},"type":"object"},"rectangular":{"description":"Rectangular Field Of'
      + ' View Scan Pattern","required":["phi_start","phi_stop","phi_increment"'
      + ',"theta_start","theta_stop","theta_increment"],"properties":{"phi_incr'
      + 'ement":{"minimum":0.0,"description":"Increment of phi angle in SOCS [d'
      + 'eg]","maximum":90.0,"type":"number"},"theta_stop":{"minimum":0.0,"desc'
      + 'ription":"Stop theta angle in SOCS [deg]","maximum":180.0,"type":"numb'
      + 'er"},"phi_stop":{"minimum":0.0,"description":"Stop phi angle in SOCS ['
      + 'deg]","maximum":720.0,"type":"number"},"theta_increment":{"minimum":0.'
      + '0,"description":"Increment of theta angle in SOCS [deg]","maximum":90.'
      + '0,"type":"number"},"theta_start":{"minimum":0.0,"description":"Start '
      + 'theta angle in SOCS [deg]","maximum":180.0,"type":"number"},"phi_start'
      + '":{"minimum":0.0,"description":"Start phi angle in SOCS [deg]","maximu'
      + 'm":360.0,"type":"number"},"program":{"$ref":"#/definitions/program"}},'
      + '"type":"object"},"segments":{"description":"Segmented Line Scan Patter'
      + 'n","required":["list"],"properties":{"list":{"type":"array","items":{"'
      + 'description":"Line Scan Segment","required":["start","stop","increment'
      + '"],"properties":{"start":{"minimum":0.0,"description":"Start angle in '
      + 'SOCS [deg]","maximum":360.0,"type":"number"},"increment":{"minimum":0.'
      + '0,"description":"Increment of angle in SOCS [deg]","maximum":90.0,"typ'
      + 'e":"number"},"stop":{"minimum":0.0,"description":"Stop angle in SOCS ['
      + 'deg]","maximum":720.0,"type":"number"}},"type":"object"}},"program":{"'
      + '$ref":"#/definitions/program"}},"type":"object"}},"description":"Scan '
      + 'pattern description"}'
    );

    Example : (''
      + '{"rectangular":{"phi_increment":0.04,"theta_stop":130.0,"phi_stop":270'
      + '.0,"theta_increment":0.04,"theta_start":30.0,"phi_start":45.0,"program'
      + '":{"name":"High Speed","laser_prr":100000.0}}}'
    );
  );

// Details about laser shot files
const
  RDB_RIEGL_SHOT_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.shot_info';
    Title       : 'Shot Information';
    Description : 'Details about laser shot files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","title":"Shot Inf'
      + 'ormation","properties":{"shot_file":{"type":"object","properties":{"fi'
      + 'le_uuid":{"description":"File''s Universally Unique Identifier (RFC '
      + '4122)","type":"string"},"file_extension":{"description":"Shot file '
      + 'extension, without the leading dot","type":"string"}},"required":["fil'
      + 'e_extension"]}},"type":"object","description":"Details about laser '
      + 'shot files"}'
    );

    Example : (''
      + '{"shot_file":{"file_uuid":"26a00815-67c0-4bff-8fe8-c577378fe663","file'
      + '_extension":"sodx"}}'
    );
  );

// Point filters applied in addition to the application-defined filters
const
  RDB_RIEGL_STORED_FILTERS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.stored_filters';
    Title       : 'Stored Filters';
    Description : 'Point filters applied in addition to the application-defined filters';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Stored filters","type":"object","$schema":"http://json-schem'
      + 'a.org/draft-04/schema#","required":["activated","filters"],"properties'
      + '":{"filters":{"description":"List of point '
      + 'filters","items":{"description":"Point filter definition","required":['
      + '"activated","title","description","filter"],"properties":{"title":{"de'
      + 'scription":"A short filter title (e.g. for display in a selection '
      + 'list)","type":"string"},"filter":{"description":"The RDB filter string'
      + ' to apply (e.g. when reading points or index), details see '
      + 'documentation of function '
      + 'select()","type":"string"},"description":{"description":"A brief '
      + 'description of the filter (e.g. for display in a '
      + 'tooltip)","type":"string"},"activated":{"description":"Apply (''true'') '
      + 'or ignore (''false'') this filter","type":"boolean"}},"type":"object"},"'
      + 'type":"array"},"activated":{"description":"Apply (''true'') or ignore '
      + '(''false'') all filters","type":"boolean"}},"description":"Point filters'
      + ' applied in addition to the application-defined filters"}'
    );

    Example : (''
      + '{"filters":[{"title":"Ignore uncertain points from MTA '
      + 'resolution","filter":"riegl.mta_uncertain_point == '
      + '0","description":"Ignore points with uncertain MTA zone '
      + 'assignment","activated":false},{"title":"Ignore points below dynamic '
      + 'trigger level","filter":"riegl.dyntrig_uncertain_point == '
      + '0","description":"Ignore points with an echo signal amplitude below '
      + 'the dynamic trigger","activated":false},{"title":"Ignore points '
      + 'outside outer AABB","filter":"riegl.point_outside_aabb_bocs == '
      + '0","description":"Ignore points that are outside the outer AABB in '
      + 'BOCS","activated":false},{"title":"Ignore points inside inner '
      + 'AABB","filter":"riegl.point_inside_aabb_bocs == '
      + '0","description":"Ignore points that are inside the inner AABB in '
      + 'BOCS","activated":false}],"activated":true}'
    );
  );

// Details of major system components like lidar sensors, cameras and navigation devices
const
  RDB_RIEGL_SYSTEM_DESCRIPTION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.system_description';
    Title       : 'System Description';
    Description : 'Details of major system components like lidar sensors, cameras and navigation devices';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"System Description","type":"object","$schema":"http://json-s'
      + 'chema.org/draft-04/schema#","required":["$class","version","author","t'
      + 'imestamp","system"],"properties":{"$class":{"description":"Object '
      + 'class name","enum":["Document"],"type":"string"},"timestamp":{"descrip'
      + 'tion":"Date and time of creation (e.g. 2019-06-19T13:32:10+02:00)","ty'
      + 'pe":"string"},"author":{"description":"Name of the author that created'
      + ' the document","type":"string"},"version":{"description":"Document '
      + 'format version","type":"string"},"system":{"description":"The actual '
      + 'system description, details see documentation of RIEGL System '
      + 'Description","type":"object"}},"description":"Details of major system '
      + 'components like lidar sensors, cameras and navigation devices"}'
    );

    Example : (''
      + '{"$class":"Document","timestamp":"2022-09-30T11:56:26+00:00","author":'
      + '"RIEGL LMS GmbH, Austria","version":"1.2.1","system":{"details":"see '
      + 'documentation of RIEGL System Description"}}'
    );
  );

// Conversion of background radiation raw values to temperatures in °C
const
  RDB_RIEGL_TEMPERATURE_CALCULATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.temperature_calculation';
    Title       : 'Temperature Calculation Table';
    Description : 'Conversion of background radiation raw values to temperatures in °C';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Temperature Calculation Table","type":"object","$schema":"ht'
      + 'tp://json-schema.org/draft-04/schema#","definitions":{"conversion_tabl'
      + 'e":{"type":"object","properties":{"value":{"type":"array","items":{"ty'
      + 'pe":"number"},"description":"LSB [1]"},"temperature":{"type":"array","'
      + 'items":{"type":"number"},"description":"Temperature [\u00b0C]"}},"requ'
      + 'ired":["value","temperature"]}},"properties":{"InGaAs_Si_Difference":{'
      + '"description":"Conversion table for InGaAs - Si difference","$ref":"#/'
      + 'definitions/conversion_table"},"Si":{"description":"Conversion table '
      + 'for Si channel","$ref":"#/definitions/conversion_table"},"InGaAs":{"de'
      + 'scription":"Conversion table for InGaAs channel","$ref":"#/definitions'
      + '/conversion_table"}},"description":"Conversion of background radiation'
      + ' raw values to temperatures in \u00b0C"}'
    );

    Example : (''
      + '{"InGaAs_Si_Difference":{"value":[1000.0,1100.090029602954,1200.044251'
      + '83874,1300.1342814416948,1400.0885036774805,1500.0427259132668,1600.13'
      + '27555162209,1700.0869777520065,1800.0411999877924],"temperature":[1749'
      + '.977111117893,1749.977111117893,1749.977111117893,1749.977111117893,17'
      + '49.977111117893,1749.977111117893,1744.7813348796044,1681.997131260109'
      + '2,1622.3944822534868]},"Si":{"value":[0.0,64.00097659230323,128.001953'
      + '1846065,192.0029297769097,256.0039063692129,320.00488296151616,384.005'
      + '8595538194,448.0068361461226,512.0078127384259],"temperature":[546.300'
      + '048828125,548.8164051212026,551.3143938500972,554.0144257850053,556.60'
      + '4252334815,559.2124464488079,561.8022729986177,564.4104671126105,567.0'
      + '002936624203]},"InGaAs":{"value":[0.0,64.00097659230323,128.0019531846'
      + '065,192.0029297769097,256.0039063692129,320.00488296151616,384.0058595'
      + '538194,448.0068361461226,512.0078127384259],"temperature":[307.2219672'
      + '2535614,309.1153478247277,311.1188086915047,313.10025350480055,315.213'
      + '7946389828,317.2172555057597,319.2207163725366,321.2021611858325,323.3'
      + '157023200148]}}'
    );
  );

// Base of timestamps (epoch)
const
  RDB_RIEGL_TIME_BASE : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.time_base';
    Title       : 'Time Base';
    Description : 'Base of timestamps (epoch)';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Time Base","type":"object","$schema":"http://json-schema.org'
      + '/draft-04/schema#","required":["epoch","source"],"properties":{"source'
      + '":{"description":"Timestamp source","enum":["unknown","RTC","GNSS"],"t'
      + 'ype":"string"},"system":{"description":"Time system (time standard)","'
      + 'enum":["unknown","UTC","GPS"],"type":"string"},"epoch":{"description":'
      + '"Date and time of timestamp ''0'' as proposed by RFC 3339 (e.g. '
      + '2015-10-27T00:00:00+01:00).","type":"string"}},"description":"Base of '
      + 'timestamps (epoch)"}'
    );

    Example : (''
      + '{"source":"GNSS","system":"UTC","epoch":"2015-10-27T00:00:00+00:00"}'
    );
  );

// Details about position+orientation files
const
  RDB_RIEGL_TRAJECTORY_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.trajectory_info';
    Title       : 'Trajectory Information';
    Description : 'Details about position+orientation files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Trajectory Information","type":"object","$schema":"http://js'
      + 'on-schema.org/draft-04/schema#","required":["time_interval","navigatio'
      + 'n_frame"],"properties":{"software":{"description":"Software that '
      + 'calculated the trajectory (this may be the same or different software '
      + 'than the one that created the '
      + 'file)","type":"string"},"location":{"description":"Project location, '
      + 'e.g. city/state/country","type":"string"},"settings":{"description":"S'
      + 'ettings used to calculate the trajectory (descriptive '
      + 'text)","type":"string"},"field_of_application":{"description":"Field '
      + 'of application","enum":["unknown","SLS","TLS","KLS","MLS","ULS","ALS",'
      + '"BLS","ILS"],"type":"string"},"device":{"description":"Navigation '
      + 'device, e.g. name/type/serial","type":"string"},"time_interval":{"desc'
      + 'ription":"Time interval statistics","required":["minimum","average","m'
      + 'aximum","std_dev"],"properties":{"minimum":{"description":"Minimum '
      + 'time interval [s]","type":"number"},"average":{"description":"Average '
      + 'time interval [s]","type":"number"},"std_dev":{"description":"Standard'
      + ' deviation of intervals '
      + '[s]","type":"number"},"maximum":{"description":"Maximum time interval '
      + '[s]","type":"number"}},"type":"object"},"navigation_frame":{"descripti'
      + 'on":"Navigation frame (NED: North-East-Down, ENU: East-North-Up)","enu'
      + 'm":["unknown","NED","ENU"],"type":"string"},"project":{"description":"'
      + 'Project name","type":"string"},"company":{"description":"Company '
      + 'name","type":"string"}},"description":"Details about '
      + 'position+orientation files"}'
    );

    Example : (''
      + '{"software":"Navigation Software XYZ","location":"Horn","settings":"de'
      + 'fault","field_of_application":"MLS","device":"IMU Model 12/1, Serial# '
      + '12345","time_interval":{"minimum":0.00500032,"average":0.00500053,"std'
      + '_dev":5.51e-07,"maximum":0.005004883},"navigation_frame":"NED","projec'
      + 't":"Campaign 3","company":"RIEGL LMS"}'
    );
  );

// Trigger-Timestamping-Unit/IP configuration
const
  RDB_RIEGL_TTIP_CONFIGURATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.ttip_configuration';
    Title       : 'TTIP Configuration';
    Description : 'Trigger-Timestamping-Unit/IP configuration';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"TTIP Configuration","type":"object","$schema":"http://json-s'
      + 'chema.org/draft-04/schema#","required":["ttip_version","num_channel","'
      + 'ext_channel","ext_signal","ext_delay","ext_subdivider","ext_bitmask","'
      + 'dmi_incr","dmi_min_time","dmi_max_time","dmi_dist_per_tick","channel",'
      + '"output_descr","input_descr","output_usage","input_usage","out_polarit'
      + 'y","out_duration","out_interval","out_delay","out_num_pulses","in_pola'
      + 'rity","in_min_duration","in_max_duration","in_max_delay"],"properties"'
      + ':{"out_polarity":{"minimum":0,"description":"0 .. positive edge, 1 .. '
      + 'negative edge","type":"integer"},"num_channel":{"minimum":0,"descripti'
      + 'on":"number of input/output channels","type":"integer"},"input_usage":'
      + '{"minimum":0,"description":"0 .. deactivated, 1 .. just detecting and '
      + 'timestamping","type":"integer"},"out_duration":{"minimum":0,"descripti'
      + 'on":"output pulse duration [0.1 '
      + 'msec]","type":"integer"},"output_descr":{"description":"descriptive st'
      + 'ring","type":"string"},"in_max_duration":{"minimum":0,"description":"s'
      + 'tops measurement of pulse duration of input signal [0.1 '
      + 'msec]","type":"integer"},"ext_signal":{"minimum":0,"description":"0 ..'
      + ' use input signal, 1 .. use output signal of channel","type":"integer"'
      + '},"ext_channel":{"minimum":0,"description":"ID of channel used as '
      + 'external trigger input, 32 indicates '
      + 'none","type":"integer"},"in_polarity":{"minimum":0,"description":"0 ..'
      + ' positive edge, 1 .. negative edge","type":"integer"},"ext_bitmask":{"'
      + 'minimum":0,"description":"defines which of the internal pulse '
      + 'generators are to be started","type":"integer"},"in_max_delay":{"minim'
      + 'um":0,"description":"maximum delay to output pulse before fake event '
      + 'is generated [0.1 msec], zero indicates that no fake events are genera'
      + 'ted","type":"integer"},"out_num_pulses":{"minimum":0,"description":"nu'
      + 'mber of output pulses to be generated, 0 .. infinite","type":"integer"'
      + '},"ext_delay":{"minimum":0,"description":"external trigger, time delay'
      + ' [0.1 msec]","type":"integer"},"dmi_min_time":{"minimum":0,"descriptio'
      + 'n":"dmi, minimum time interval between trigger events [0.1 msec]","typ'
      + 'e":"integer"},"dmi_max_time":{"minimum":0,"description":"dmi, maximum '
      + 'time interval between trigger events [0.1 msec]","type":"integer"},"ou'
      + 't_delay":{"minimum":0,"description":"output pulse initial delay after '
      + 'start [0.1 msec]","type":"integer"},"ext_subdivider":{"minimum":0,"des'
      + 'cription":"reduces the frequency, default '
      + '1","type":"integer"},"output_usage":{"minimum":0,"description":"0 .. '
      + 'no output, 1 .. output derived from internal clock, 2 .. output '
      + 'derived from dmi, 3 .. output derived from external signal, 4 .. '
      + 'output static low, 5 .. output static '
      + 'high","type":"integer"},"channel":{"minimum":0,"description":"ID of '
      + 'input/output channel","type":"integer"},"in_min_duration":{"minimum":0'
      + ',"description":"input signals with smaller pulse durations are ignored'
      + ' [0.1 '
      + 'msec]","type":"integer"},"dmi_dist_per_tick":{"description":"dmi, '
      + 'distance per tick, just informative [m]","type":"number"},"out_interva'
      + 'l":{"minimum":0,"description":"output pulse interval [0.1 '
      + 'msec]","type":"integer"},"dmi_incr":{"description":"dmi, increment in '
      + 'ticks","type":"integer"},"input_descr":{"description":"descriptive str'
      + 'ing","type":"string"},"ttip_version":{"minimum":0,"description":"follo'
      + 'wing main.sub.ss.sss","type":"integer"}},"description":"Trigger-Timest'
      + 'amping-Unit/IP configuration"}'
    );

    Example : (''
      + '{"out_polarity":0,"num_channel":9,"input_usage":1,"out_duration":300,"'
      + 'output_descr":"Port 1 - Trigger","in_max_duration":10000,"ext_signal":'
      + '0,"ext_channel":32,"in_polarity":0,"ext_bitmask":0,"in_max_delay":9990'
      + ',"out_num_pulses":1,"ext_delay":0,"dmi_min_time":0,"dmi_max_time":0,"o'
      + 'ut_delay":0,"ext_subdivider":1,"output_usage":1,"channel":0,"in_min_du'
      + 'ration":0,"dmi_dist_per_tick":0.0,"out_interval":10000,"dmi_incr":0,"i'
      + 'nput_descr":"Port 1 - Exposure","ttip_version":1}'
    );
  );

// Details about vertex file
const
  RDB_RIEGL_VERTEX_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.vertex_info';
    Title       : 'Vertex Information';
    Description : 'Details about vertex file';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","title":"Vertex I'
      + 'nformation","properties":{"vertex_file":{"type":"object","properties":'
      + '{"file_uuid":{"description":"File''s Universally Unique Identifier (RFC'
      + ' 4122)","type":"string"},"file_extension":{"description":"Vertex file '
      + 'extension, without the leading dot","type":"string"}},"required":["fil'
      + 'e_extension"]}},"type":"object","description":"Details about vertex '
      + 'file"}'
    );

    Example : (''
      + '{"vertex_file":{"file_uuid":"51534d95-d71f-4f36-ae1a-3e63a21fd1c7","fi'
      + 'le_extension":"vtx"}}'
    );
  );

// Details about the voxels contained in the file
const
  RDB_RIEGL_VOXEL_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.voxel_info';
    Title       : 'Voxel Information';
    Description : 'Details about the voxels contained in the file';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Voxel Information","oneOf":[{"additionalProperties":false,"p'
      + 'roperties":{"voxel_origin":{"$ref":"#/definitions/voxel_origin_enum"},'
      + '"voxel_type":{"$ref":"#/definitions/voxel_type"},"size":{"description"'
      + ':"Size of voxels in file coordinate system.","oneOf":[{"$ref":"#/defin'
      + 'itions/voxel_size"},{"$ref":"#/definitions/voxel_size_cubic"}]},"shape'
      + '_thresholds":{"$ref":"#/definitions/shape_thresholds"}},"required":["s'
      + 'ize","voxel_origin","voxel_type"]},{"additionalProperties":false,"prop'
      + 'erties":{"voxel_origin":{"oneOf":[{"$ref":"#/definitions/voxel_origin_'
      + 'enum"},{"description":"The base point of the voxel grid. Used together'
      + ' with <tt>voxel_size</tt> and <tt>voxel_index</tt> to compute actual '
      + 'point coordinates.","$ref":"#/definitions/voxel_origin_point"}]},"voxe'
      + 'l_type":{"$ref":"#/definitions/voxel_type"},"size":{"description":"Siz'
      + 'e of voxels in file coordinate system.","$ref":"#/definitions/voxel_si'
      + 'ze"},"size_llcs":{"description":"Size of voxels in a locally levelled '
      + 'cartesian coordinate system (xyz). This is only used for voxels based '
      + 'on a map projection.","$ref":"#/definitions/voxel_size"},"reference_po'
      + 'int":{"type":"array","description":"Point in WGS84 geodetic decimal '
      + 'degree (EPSG:4326) that was used to compute the projection distortion '
      + 'parameters. The coefficient order is latitude, longitude. Only voxels '
      + 'with corresponding geo_tag, voxel_size and reference_point can be '
      + 'reliably processed together. This entry is available for voxel files '
      + 'in projected CRS only.","minItems":2,"maxItems":2,"items":{"minimum":-'
      + '180,"type":"number","maximum":180}},"shape_thresholds":{"$ref":"#/defi'
      + 'nitions/shape_thresholds"}},"required":["reference_point","size_llcs",'
      + '"size","voxel_origin","voxel_type"]}],"type":"object","$schema":"http:'
      + '//json-schema.org/draft-04/schema#","definitions":{"edge_length":{"exc'
      + 'lusiveMinimum":true,"description":"Length of voxel edge [m].","minimum'
      + '":0,"type":"number"},"voxel_type":{"description":"Whether a point in a'
      + ' voxel represents its center or its centroid. If type is '
      + '<tt>index</tt> there is no point but only an integer voxel index.","en'
      + 'um":["center","centroid","index"],"default":"centroid"},"voxel_size_cu'
      + 'bic":{"type":"number","$ref":"#/definitions/edge_length"},"voxel_size"'
      + ':{"type":"array","description":"Size of voxels.","minItems":3,"maxItem'
      + 's":3,"items":{"$ref":"#/definitions/edge_length"}},"voxel_origin_enum"'
      + ':{"description":"Defines whether the voxel''s center or a corner is '
      + 'placed on CRS origin <tt>(0/0/0)</tt>.","enum":["center","corner"],"de'
      + 'fault":"corner"},"shape_thresholds":{"type":"object","description":"Th'
      + 'resholds used to compute the voxel''s shape_id value.","properties":{"l'
      + 'ine":{"exclusiveMinimum":true,"description":"If the biggest eigenvalue'
      + ' is bigger than the median eigenvalue * line_threshold, the voxel is '
      + 'considered a line.","minimum":1,"type":"number"},"plane":{"minimum":0,'
      + '"description":"If the smallest eigenvalue is smaller than the median '
      + 'eigenvalue * plane_threshold, the voxel is considered a plane.","type"'
      + ':"number","exclusiveMinimum":true,"exclusiveMaximum":true,"maximum":1}'
      + '},"required":["plane","line"]},"voxel_origin_point":{"type":"array","d'
      + 'escription":"Origin point for all voxel indices in voxel CRS.","minIte'
      + 'ms":3,"maxItems":3,"items":{"type":"number"}}},"description":"Details '
      + 'about the voxels contained in the file"}'
    );

    Example : (''
      + '{"voxel_origin":"corner","voxel_type":"centroid","size":[0.59716428347'
      + '79395,0.5971642834779395,0.5143705304787237],"size_llcs":[0.5156575252'
      + '891171,0.5130835356683303,0.5143705304787237],"reference_point":[48,16'
      + '],"shape_thresholds":{"line":6,"plane":0.16}}'
    );
  );

// Settings for waveform averaging
const
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.waveform_averaging_settings';
    Title       : 'Waveform Averaging Settings';
    Description : 'Settings for waveform averaging';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Waveform Averaging Settings","type":"object","$schema":"http'
      + '://json-schema.org/draft-04/schema#","required":["num_shots","mta_zone'
      + '"],"properties":{"trim":{"minimum":0,"type":"number","default":0,"maxi'
      + 'mum":0.5,"description":"Percentage for robust averaging."},"num_shots"'
      + ':{"minimum":1,"type":"integer","description":"Number of consecutive '
      + 'shots to be used for averaging."},"mta_zone":{"minimum":1,"type":"inte'
      + 'ger","description":"Fixed MTA zone for '
      + 'averaging."}},"description":"Settings for waveform averaging"}'
    );

    Example : (''
      + '{"trim":0.05,"num_shots":7,"mta_zone":1}'
    );
  );

// Details about waveform files
const
  RDB_RIEGL_WAVEFORM_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.waveform_info';
    Title       : 'Waveform Information';
    Description : 'Details about waveform files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"type":"object","title":"Waveform Information","required":["sample_bl'
      + 'ock_file","sample_data_files"],"$schema":"http://json-schema.org/draft'
      + '-04/schema#","properties":{"range_offset_m":{"description":"Calibrated'
      + ' device specific range offset for waveform analysis by system response'
      + ' fitting in meters.","type":"number"},"sample_data_files":{"type":"arr'
      + 'ay","items":{"type":"object","properties":{"channel_name":{"descriptio'
      + 'n":"Sample block channel name","type":"string"},"delta_st":{"descripti'
      + 'on":"reserved","type":"number"},"file_uuid":{"description":"File''s '
      + 'Universally Unique Identifier (RFC 4122)","type":"string"},"laser_wave'
      + 'length":{"exclusiveMinimum":false,"description":"Laser wavelength in '
      + 'meters (0 = unknown)","minimum":0,"type":"number"},"sample_interval":{'
      + '"exclusiveMinimum":false,"description":"Sampling interval in seconds",'
      + '"minimum":0,"type":"number"},"channel":{"exclusiveMinimum":false,"type'
      + '":"integer","minimum":0,"description":"Sample block channel number '
      + '(255 = invalid)","exclusiveMaximum":false,"maximum":255},"sample_bits"'
      + ':{"exclusiveMinimum":false,"type":"integer","minimum":0,"description":'
      + '"Bitwidth of samples (e.g. 10 bit, 12 bit)","exclusiveMaximum":false,"'
      + 'maximum":32},"file_extension":{"description":"Sample data file '
      + 'extension, without the leading dot","type":"string"}},"required":["cha'
      + 'nnel","channel_name","sample_interval","sample_bits","laser_wavelength'
      + '","delta_st","file_extension"]}},"range_offset_waveform_samples_m":{"d'
      + 'escription":"Calibrated device specific range offset for waveform '
      + 'samples in meters.","type":"number"},"sample_block_file":{"type":"obje'
      + 'ct","properties":{"file_uuid":{"description":"File''s Universally '
      + 'Unique Identifier (RFC '
      + '4122)","type":"string"},"file_extension":{"description":"Sample block '
      + 'file extension, without the leading dot","type":"string"}},"required":'
      + '["file_extension"]}},"description":"Details about waveform files"}'
    );

    Example : (''
      + '{"range_offset_waveform_samples_m ":7.283,"range_offset_m":3.1415,"sam'
      + 'ple_data_files":[{"channel_name":"high_power","delta_st":0,"file_uuid"'
      + ':"da084413-e3e8-4655-a122-071de8490d8e","laser_wavelength":0,"sample_i'
      + 'nterval":1.00503e-09,"channel":0,"sample_bits":12,"file_extension":"sp'
      + '0"},{"channel_name":"low_power","delta_st":0,"file_uuid":"93585b5e-5ea'
      + '9-43a1-947b-e7ba3be642d2","laser_wavelength":0,"sample_interval":1.005'
      + '03e-09,"channel":1,"sample_bits":12,"file_extension":"sp1"},{"channel_'
      + 'name":"wwf","delta_st":0,"file_uuid":"9d2298c4-1036-464f-b5cb-1cf8e517'
      + 'f3a0","laser_wavelength":0,"sample_interval":1.00503e-09,"channel":5,"'
      + 'sample_bits":12,"file_extension":"sp5"}],"sample_block_file":{"file_uu'
      + 'id":"93a03615-66c0-4bea-8ff8-c577378fe660","file_extension":"sbx"}}'
    );
  );

// Scanner settings for waveform output
const
  RDB_RIEGL_WAVEFORM_SETTINGS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.waveform_settings';
    Title       : 'Waveform Settings';
    Description : 'Scanner settings for waveform output';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","title":"Waveform'
      + ' Settings","items":{"type":"object","properties":{"sbl_name":{"descrip'
      + 'tion":"Name of sample block, e.g.: wfm, '
      + 'wwf","type":"string"},"pass_ampl_greater":{"description":"Threshold '
      + 'for amplitude greater than '
      + '[dB]","type":"number"},"smart_enabled":{"description":"Smart waveform '
      + 'output '
      + 'enabled","type":"boolean"},"channel_idx_mask":{"description":"Bit mask'
      + ' for channels which belong to sbl_name: Channel 0 = Bit0, Channel 1 = '
      + 'Bit1, ...","type":"integer"},"pass_dev_less":{"description":"Threshold'
      + ' for deviation less than '
      + '[1]","type":"integer"},"pass_ampl_less":{"description":"Threshold for '
      + 'amplitude less than '
      + '[dB]","type":"number"},"enabled":{"description":"Waveform output '
      + 'enabled","type":"boolean"},"logic_expression":{"description":"Logic '
      + 'expression of smart waveforms '
      + 'filter","type":"string"},"pass_rng_less":{"description":"Threshold for'
      + ' range less than '
      + '[m]","type":"number"},"pass_rng_greater":{"description":"Threshold for'
      + ' range greater than '
      + '[m]","type":"number"},"pass_dev_greater":{"description":"Threshold for'
      + ' deviation greater than [1]","type":"integer"}},"required":["sbl_name"'
      + ',"enabled","channel_idx_mask"]},"type":"array","description":"Scanner '
      + 'settings for waveform output"}'
    );

    Example : (''
      + '[{"sbl_name":"wfm","pass_ampl_greater":1.0,"smart_enabled":true,"chann'
      + 'el_idx_mask":11,"pass_ampl_less":5.0,"enabled":true,"pass_rng_less":13'
      + '.11,"pass_rng_greater":9.27},{"sbl_name":"wwf","enabled":false,"channe'
      + 'l_idx_mask":32}]'
    );
  );

// Window analysis data estimated from scandata and resulting filter parameters
const
  RDB_RIEGL_WINDOW_ANALYSIS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.window_analysis';
    Title       : 'Window Analysis';
    Description : 'Window analysis data estimated from scandata and resulting filter parameters';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Window Analysis","type":"object","$schema":"http://json-sche'
      + 'ma.org/draft-04/schema#","required":["result","filter","settings"],"pr'
      + 'operties":{"settings":{"type":"object","properties":{"range":{"type":"'
      + 'object","properties":{"sigma_factor":{"type":"number"},"additive_value'
      + '":{"type":"number"}},"required":["sigma_factor","additive_value"]},"am'
      + 'plitude":{"type":"object","properties":{"sigma_factor":{"type":"number'
      + '"},"additive_value":{"type":"number"}},"required":["sigma_factor","add'
      + 'itive_value"]}},"required":["range","amplitude"]},"filter":{"type":"ob'
      + 'ject","properties":{"range_max":{"type":"array","description":"[m]","i'
      + 'tems":{"type":"number"}},"amplitude_max":{"type":"array","description"'
      + ':"[dB]","items":{"type":"number"}},"angle":{"type":"array","descriptio'
      + 'n":"[deg]","items":{"type":"number"}},"range_min":{"type":"array","des'
      + 'cription":"[m]","items":{"type":"number"}}},"required":["angle","range'
      + '_min","range_max","amplitude_max"]},"result":{"type":"object","propert'
      + 'ies":{"timestamp":{"type":"array","description":"[s]","items":{"type":'
      + '"number"}},"angle":{"type":"array","description":"[deg]","items":{"typ'
      + 'e":"number"}},"amplitude_mean":{"type":"array","description":"[dB]","i'
      + 'tems":{"type":"number"}},"amplitude_offset":{"type":"array","descripti'
      + 'on":"[dB]","items":{"type":"number"}},"amplitude_sigma":{"type":"array'
      + '","description":"[dB]","items":{"type":"number"}},"range_sigma":{"type'
      + '":"array","description":"[m]","items":{"type":"number"}},"range_mean":'
      + '{"type":"array","description":"[m]","items":{"type":"number"}}},"requi'
      + 'red":["angle","range_mean","range_sigma","amplitude_mean","amplitude_s'
      + 'igma","amplitude_offset"]}},"description":"Window analysis data '
      + 'estimated from scandata and resulting filter parameters"}'
    );

    Example : (''
      + '{"settings":{"range":{"sigma_factor":8,"additive_value":0.1},"amplitud'
      + 'e":{"sigma_factor":4,"additive_value":1.0}},"filter":{"range_max":[0.4'
      + '24,0.425,0.426,0.427,0.428,0.428,0.429,0.43,0.431,0.431,0.432],"amplit'
      + 'ude_max":[8.04,8.01,7.99,7.96,7.93,7.9,7.88,7.85,7.83,7.8,7.78],"angle'
      + '":[14.9,15.0,15.1,15.2,15.3,15.4,15.5,15.6,15.7,15.8,15.9],"range_min"'
      + ':[-0.208,-0.21,-0.212,-0.214,-0.216,-0.218,-0.219,-0.221,-0.223,-0.225'
      + ',-0.227]},"result":{"timestamp":[408.4441,411.4443],"angle":[14.9,15.0'
      + ',15.1,15.2,15.3,15.4,15.5,15.6,15.7,15.8,15.9],"amplitude_mean":[5.347'
      + '396,5.263155,5.224655,5.179926,5.097782,5.116479,5.051756,4.983473,5.0'
      + '07885,5.002441,4.982],"amplitude_offset":[1.9,1.9],"amplitude_sigma":['
      + '0.4272844,0.4298479,0.4236816,0.4283583,0.4362353,0.4315141,0.4373984,'
      + '0.4472798,0.4346001,0.4345487,0.4540681],"range_sigma":[0.01869652,0.0'
      + '2151435,0.01747969,0.01918765,0.01945776,0.01934862,0.01955329,0.02225'
      + '589,0.02229977,0.01899122,0.02009433],"range_mean":[0.1105621,0.107956'
      + '4,0.1087088,0.1067261,0.1054582,0.1090412,0.102871,0.1019044,0.1051523'
      + ',0.1058445,0.1031261]}}'
    );
  );

// Correction parameters for window glass echoes
const
  RDB_RIEGL_WINDOW_ECHO_CORRECTION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.window_echo_correction';
    Title       : 'Window Echo Correction';
    Description : 'Correction parameters for window glass echoes';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Window Echo Correction","type":"object","$schema":"http://js'
      + 'on-schema.org/draft-04/schema#","required":["amplitude","range","slice'
      + 's"],"properties":{"slices":{"type":"array","items":{"type":"object","r'
      + 'equired":["amplitude","table"],"properties":{"table":{"type":"array","'
      + 'minItems":1,"items":{"type":"array","minItems":1,"items":{"type":"arra'
      + 'y","minItems":3,"items":{"description":"Table cell (item 0: amplitude '
      + 'in dB, 1: range in m, 2: '
      + 'flags)","type":"number"},"maxItems":3,"description":"Table column (= '
      + 'range axis)"},"description":"Table row (= amplitude '
      + 'axis)"},"description":"Correction table (dimension defined by the '
      + '''amplitude'' and ''range'' '
      + 'objects)"},"amplitude":{"type":"number","description":"Window echo '
      + 'amplitude of slice in dB"}},"description":"Window echo correction '
      + 'parameter slice"}},"amplitude":{"type":"object","required":["minimum",'
      + '"maximum","entries"],"properties":{"minimum":{"minimum":0.0,"type":"nu'
      + 'mber","description":"Minimum amplitude in '
      + 'dB"},"entries":{"minimum":1,"type":"integer","description":"Number of '
      + 'amplitude entries"},"maximum":{"minimum":0.0,"type":"number","descript'
      + 'ion":"Maximum amplitude in dB"}},"description":"Amplitude axis of '
      + 'correction table"},"range":{"type":"object","required":["minimum","max'
      + 'imum","entries"],"properties":{"minimum":{"minimum":-2.0,"type":"numbe'
      + 'r","maximum":2.0,"description":"Minimum range in '
      + 'm"},"entries":{"minimum":1,"type":"integer","description":"Number of '
      + 'range entries"},"maximum":{"minimum":-2.0,"type":"number","maximum":2.'
      + '0,"description":"Maximum range in m"}},"description":"Range axis of '
      + 'correction table"}},"description":"Correction parameters for window '
      + 'glass echoes"}'
    );

    Example : (''
      + '{"slices":[{"table":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]],"amplitude"'
      + ':1.5},{"table":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]],"amplitude":2.0}'
      + '],"amplitude":{"minimum":2,"entries":128,"maximum":20},"range":{"minim'
      + 'um":-1.5060822940732335,"entries":128,"maximum":1.5060822940732335}}'
    );
  );

// Table of all meta data item details records
const
  RDB_META_DATA_ITEMS : array of PRDBPointcloudMetaDataItemInfo = nil; // filled during initialization

implementation

procedure FixStringEncoding;
begin
  // As the unit (.pas file) doesn't contain a BOM, we need to convert all strings
  // from UTF-8 to "native" encoding at runtime (tested on Delphi 7 and Delphi XE5)

  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Name)));
  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Title)));
  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Description)));
  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Schema)));
  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Example)));

  RDB_RIEGL_ATMOSPHERE.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Name)));
  RDB_RIEGL_ATMOSPHERE.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Title)));
  RDB_RIEGL_ATMOSPHERE.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Description)));
  RDB_RIEGL_ATMOSPHERE.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Schema)));
  RDB_RIEGL_ATMOSPHERE.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Example)));

  RDB_RIEGL_BEAM_GEOMETRY.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Name)));
  RDB_RIEGL_BEAM_GEOMETRY.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Title)));
  RDB_RIEGL_BEAM_GEOMETRY.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Description)));
  RDB_RIEGL_BEAM_GEOMETRY.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Schema)));
  RDB_RIEGL_BEAM_GEOMETRY.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Example)));

  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Name)));
  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Title)));
  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Description)));
  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Schema)));
  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Example)));

  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Name)));
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Title)));
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Description)));
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Schema)));
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Example)));

  RDB_RIEGL_DETECTION_PROBABILITY.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Name)));
  RDB_RIEGL_DETECTION_PROBABILITY.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Title)));
  RDB_RIEGL_DETECTION_PROBABILITY.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Description)));
  RDB_RIEGL_DETECTION_PROBABILITY.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Schema)));
  RDB_RIEGL_DETECTION_PROBABILITY.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Example)));

  RDB_RIEGL_DEVICE.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Name)));
  RDB_RIEGL_DEVICE.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Title)));
  RDB_RIEGL_DEVICE.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Description)));
  RDB_RIEGL_DEVICE.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Schema)));
  RDB_RIEGL_DEVICE.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Example)));

  RDB_RIEGL_DEVICE_GEOMETRY.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Name)));
  RDB_RIEGL_DEVICE_GEOMETRY.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Title)));
  RDB_RIEGL_DEVICE_GEOMETRY.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Description)));
  RDB_RIEGL_DEVICE_GEOMETRY.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Schema)));
  RDB_RIEGL_DEVICE_GEOMETRY.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Example)));

  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Name)));
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Title)));
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Description)));
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Schema)));
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Example)));

  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Name)));
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Title)));
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Description)));
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Schema)));
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Example)));

  RDB_RIEGL_DEVICES.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICES.Name)));
  RDB_RIEGL_DEVICES.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICES.Title)));
  RDB_RIEGL_DEVICES.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICES.Description)));
  RDB_RIEGL_DEVICES.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICES.Schema)));
  RDB_RIEGL_DEVICES.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICES.Example)));

  RDB_RIEGL_DYNTRIG.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DYNTRIG.Name)));
  RDB_RIEGL_DYNTRIG.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DYNTRIG.Title)));
  RDB_RIEGL_DYNTRIG.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DYNTRIG.Description)));
  RDB_RIEGL_DYNTRIG.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DYNTRIG.Schema)));
  RDB_RIEGL_DYNTRIG.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DYNTRIG.Example)));

  RDB_RIEGL_ECHO_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Name)));
  RDB_RIEGL_ECHO_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Title)));
  RDB_RIEGL_ECHO_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Description)));
  RDB_RIEGL_ECHO_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Schema)));
  RDB_RIEGL_ECHO_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Example)));

  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Name)));
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Title)));
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Description)));
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Schema)));
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Example)));

  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Name)));
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Title)));
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Description)));
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Schema)));
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Example)));

  RDB_RIEGL_GEO_TAG.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Name)));
  RDB_RIEGL_GEO_TAG.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Title)));
  RDB_RIEGL_GEO_TAG.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Description)));
  RDB_RIEGL_GEO_TAG.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Schema)));
  RDB_RIEGL_GEO_TAG.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Example)));

  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Name)));
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Title)));
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Description)));
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Schema)));
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Example)));

  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Name)));
  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Title)));
  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Description)));
  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Schema)));
  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Example)));

  RDB_RIEGL_ITEM_NAMES.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ITEM_NAMES.Name)));
  RDB_RIEGL_ITEM_NAMES.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ITEM_NAMES.Title)));
  RDB_RIEGL_ITEM_NAMES.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ITEM_NAMES.Description)));
  RDB_RIEGL_ITEM_NAMES.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ITEM_NAMES.Schema)));
  RDB_RIEGL_ITEM_NAMES.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ITEM_NAMES.Example)));

  RDB_RIEGL_LICENSES.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Name)));
  RDB_RIEGL_LICENSES.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Title)));
  RDB_RIEGL_LICENSES.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Description)));
  RDB_RIEGL_LICENSES.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Schema)));
  RDB_RIEGL_LICENSES.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Example)));

  RDB_RIEGL_MTA_SETTINGS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Name)));
  RDB_RIEGL_MTA_SETTINGS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Title)));
  RDB_RIEGL_MTA_SETTINGS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Description)));
  RDB_RIEGL_MTA_SETTINGS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Schema)));
  RDB_RIEGL_MTA_SETTINGS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Example)));

  RDB_RIEGL_NEAR_RANGE_CORRECTION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Name)));
  RDB_RIEGL_NEAR_RANGE_CORRECTION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Title)));
  RDB_RIEGL_NEAR_RANGE_CORRECTION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Description)));
  RDB_RIEGL_NEAR_RANGE_CORRECTION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Schema)));
  RDB_RIEGL_NEAR_RANGE_CORRECTION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Example)));

  RDB_RIEGL_NOISE_ESTIMATES.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Name)));
  RDB_RIEGL_NOISE_ESTIMATES.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Title)));
  RDB_RIEGL_NOISE_ESTIMATES.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Description)));
  RDB_RIEGL_NOISE_ESTIMATES.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Schema)));
  RDB_RIEGL_NOISE_ESTIMATES.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Example)));

  RDB_RIEGL_NOTCH_FILTER.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Name)));
  RDB_RIEGL_NOTCH_FILTER.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Title)));
  RDB_RIEGL_NOTCH_FILTER.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Description)));
  RDB_RIEGL_NOTCH_FILTER.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Schema)));
  RDB_RIEGL_NOTCH_FILTER.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Example)));

  RDB_RIEGL_PIXEL_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Name)));
  RDB_RIEGL_PIXEL_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Title)));
  RDB_RIEGL_PIXEL_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Description)));
  RDB_RIEGL_PIXEL_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Schema)));
  RDB_RIEGL_PIXEL_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Example)));

  RDB_RIEGL_PLANE_PATCH_MATCHING.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Name)));
  RDB_RIEGL_PLANE_PATCH_MATCHING.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Title)));
  RDB_RIEGL_PLANE_PATCH_MATCHING.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Description)));
  RDB_RIEGL_PLANE_PATCH_MATCHING.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Schema)));
  RDB_RIEGL_PLANE_PATCH_MATCHING.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Example)));

  RDB_RIEGL_PLANE_PATCH_STATISTICS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Name)));
  RDB_RIEGL_PLANE_PATCH_STATISTICS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Title)));
  RDB_RIEGL_PLANE_PATCH_STATISTICS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Description)));
  RDB_RIEGL_PLANE_PATCH_STATISTICS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Schema)));
  RDB_RIEGL_PLANE_PATCH_STATISTICS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Example)));

  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Name)));
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Title)));
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Description)));
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Schema)));
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Example)));

  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Name)));
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Title)));
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Description)));
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Schema)));
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Example)));

  RDB_RIEGL_POINTCLOUD_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Name)));
  RDB_RIEGL_POINTCLOUD_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Title)));
  RDB_RIEGL_POINTCLOUD_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Description)));
  RDB_RIEGL_POINTCLOUD_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Schema)));
  RDB_RIEGL_POINTCLOUD_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Example)));

  RDB_RIEGL_POSE_ESTIMATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Name)));
  RDB_RIEGL_POSE_ESTIMATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Title)));
  RDB_RIEGL_POSE_ESTIMATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Description)));
  RDB_RIEGL_POSE_ESTIMATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Schema)));
  RDB_RIEGL_POSE_ESTIMATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Example)));

  RDB_RIEGL_POSE_SENSORS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Name)));
  RDB_RIEGL_POSE_SENSORS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Title)));
  RDB_RIEGL_POSE_SENSORS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Description)));
  RDB_RIEGL_POSE_SENSORS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Schema)));
  RDB_RIEGL_POSE_SENSORS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Example)));

  RDB_RIEGL_PULSE_POSITION_MODULATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Name)));
  RDB_RIEGL_PULSE_POSITION_MODULATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Title)));
  RDB_RIEGL_PULSE_POSITION_MODULATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Description)));
  RDB_RIEGL_PULSE_POSITION_MODULATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Schema)));
  RDB_RIEGL_PULSE_POSITION_MODULATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Example)));

  RDB_RIEGL_RANGE_STATISTICS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Name)));
  RDB_RIEGL_RANGE_STATISTICS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Title)));
  RDB_RIEGL_RANGE_STATISTICS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Description)));
  RDB_RIEGL_RANGE_STATISTICS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Schema)));
  RDB_RIEGL_RANGE_STATISTICS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Example)));

  RDB_RIEGL_RECEIVER_INTERNALS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Name)));
  RDB_RIEGL_RECEIVER_INTERNALS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Title)));
  RDB_RIEGL_RECEIVER_INTERNALS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Description)));
  RDB_RIEGL_RECEIVER_INTERNALS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Schema)));
  RDB_RIEGL_RECEIVER_INTERNALS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Example)));

  RDB_RIEGL_REFLECTANCE_CALCULATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Name)));
  RDB_RIEGL_REFLECTANCE_CALCULATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Title)));
  RDB_RIEGL_REFLECTANCE_CALCULATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Description)));
  RDB_RIEGL_REFLECTANCE_CALCULATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Schema)));
  RDB_RIEGL_REFLECTANCE_CALCULATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Example)));

  RDB_RIEGL_REFLECTANCE_CORRECTION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Name)));
  RDB_RIEGL_REFLECTANCE_CORRECTION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Title)));
  RDB_RIEGL_REFLECTANCE_CORRECTION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Description)));
  RDB_RIEGL_REFLECTANCE_CORRECTION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Schema)));
  RDB_RIEGL_REFLECTANCE_CORRECTION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Example)));

  RDB_RIEGL_SCAN_PATTERN.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Name)));
  RDB_RIEGL_SCAN_PATTERN.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Title)));
  RDB_RIEGL_SCAN_PATTERN.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Description)));
  RDB_RIEGL_SCAN_PATTERN.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Schema)));
  RDB_RIEGL_SCAN_PATTERN.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Example)));

  RDB_RIEGL_SHOT_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Name)));
  RDB_RIEGL_SHOT_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Title)));
  RDB_RIEGL_SHOT_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Description)));
  RDB_RIEGL_SHOT_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Schema)));
  RDB_RIEGL_SHOT_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Example)));

  RDB_RIEGL_STORED_FILTERS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_STORED_FILTERS.Name)));
  RDB_RIEGL_STORED_FILTERS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_STORED_FILTERS.Title)));
  RDB_RIEGL_STORED_FILTERS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_STORED_FILTERS.Description)));
  RDB_RIEGL_STORED_FILTERS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_STORED_FILTERS.Schema)));
  RDB_RIEGL_STORED_FILTERS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_STORED_FILTERS.Example)));

  RDB_RIEGL_SYSTEM_DESCRIPTION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SYSTEM_DESCRIPTION.Name)));
  RDB_RIEGL_SYSTEM_DESCRIPTION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SYSTEM_DESCRIPTION.Title)));
  RDB_RIEGL_SYSTEM_DESCRIPTION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SYSTEM_DESCRIPTION.Description)));
  RDB_RIEGL_SYSTEM_DESCRIPTION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SYSTEM_DESCRIPTION.Schema)));
  RDB_RIEGL_SYSTEM_DESCRIPTION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SYSTEM_DESCRIPTION.Example)));

  RDB_RIEGL_TEMPERATURE_CALCULATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Name)));
  RDB_RIEGL_TEMPERATURE_CALCULATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Title)));
  RDB_RIEGL_TEMPERATURE_CALCULATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Description)));
  RDB_RIEGL_TEMPERATURE_CALCULATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Schema)));
  RDB_RIEGL_TEMPERATURE_CALCULATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Example)));

  RDB_RIEGL_TIME_BASE.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Name)));
  RDB_RIEGL_TIME_BASE.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Title)));
  RDB_RIEGL_TIME_BASE.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Description)));
  RDB_RIEGL_TIME_BASE.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Schema)));
  RDB_RIEGL_TIME_BASE.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Example)));

  RDB_RIEGL_TRAJECTORY_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Name)));
  RDB_RIEGL_TRAJECTORY_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Title)));
  RDB_RIEGL_TRAJECTORY_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Description)));
  RDB_RIEGL_TRAJECTORY_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Schema)));
  RDB_RIEGL_TRAJECTORY_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Example)));

  RDB_RIEGL_TTIP_CONFIGURATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TTIP_CONFIGURATION.Name)));
  RDB_RIEGL_TTIP_CONFIGURATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TTIP_CONFIGURATION.Title)));
  RDB_RIEGL_TTIP_CONFIGURATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TTIP_CONFIGURATION.Description)));
  RDB_RIEGL_TTIP_CONFIGURATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TTIP_CONFIGURATION.Schema)));
  RDB_RIEGL_TTIP_CONFIGURATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TTIP_CONFIGURATION.Example)));

  RDB_RIEGL_VERTEX_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Name)));
  RDB_RIEGL_VERTEX_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Title)));
  RDB_RIEGL_VERTEX_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Description)));
  RDB_RIEGL_VERTEX_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Schema)));
  RDB_RIEGL_VERTEX_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Example)));

  RDB_RIEGL_VOXEL_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Name)));
  RDB_RIEGL_VOXEL_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Title)));
  RDB_RIEGL_VOXEL_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Description)));
  RDB_RIEGL_VOXEL_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Schema)));
  RDB_RIEGL_VOXEL_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Example)));

  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Name)));
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Title)));
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Description)));
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Schema)));
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Example)));

  RDB_RIEGL_WAVEFORM_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Name)));
  RDB_RIEGL_WAVEFORM_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Title)));
  RDB_RIEGL_WAVEFORM_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Description)));
  RDB_RIEGL_WAVEFORM_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Schema)));
  RDB_RIEGL_WAVEFORM_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Example)));

  RDB_RIEGL_WAVEFORM_SETTINGS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Name)));
  RDB_RIEGL_WAVEFORM_SETTINGS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Title)));
  RDB_RIEGL_WAVEFORM_SETTINGS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Description)));
  RDB_RIEGL_WAVEFORM_SETTINGS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Schema)));
  RDB_RIEGL_WAVEFORM_SETTINGS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Example)));

  RDB_RIEGL_WINDOW_ANALYSIS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Name)));
  RDB_RIEGL_WINDOW_ANALYSIS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Title)));
  RDB_RIEGL_WINDOW_ANALYSIS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Description)));
  RDB_RIEGL_WINDOW_ANALYSIS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Schema)));
  RDB_RIEGL_WINDOW_ANALYSIS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Example)));

  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Name)));
  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Title)));
  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Description)));
  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Schema)));
  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Example)));
end;

procedure FillMetadataArray;
var
  i : Integer;
begin
  SetLength(RDB_META_DATA_ITEMS, 52); i := -1;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_ANGULAR_NOTCH_FILTER;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_ATMOSPHERE;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_BEAM_GEOMETRY;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_CONTROL_OBJECT_CATALOG;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DETECTION_PROBABILITY;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICE;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICE_GEOMETRY;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICE_OUTPUT_LIMITS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICES;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DYNTRIG;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_ECHO_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_EXPONENTIAL_DECOMPOSITION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_GAUSSIAN_DECOMPOSITION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_GEO_TAG;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_GEOMETRIC_SCALE_FACTOR;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_GEOREFERENCING_PARAMETERS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_ITEM_NAMES;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_LICENSES;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_MTA_SETTINGS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_NEAR_RANGE_CORRECTION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_NOISE_ESTIMATES;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_NOTCH_FILTER;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PIXEL_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PLANE_PATCH_MATCHING;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PLANE_PATCH_STATISTICS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PLANE_SLOPE_CLASS_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_POINT_ATTRIBUTE_GROUPS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_POINTCLOUD_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_POSE_ESTIMATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_POSE_SENSORS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PULSE_POSITION_MODULATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_RANGE_STATISTICS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_RECEIVER_INTERNALS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_REFLECTANCE_CALCULATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_REFLECTANCE_CORRECTION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_SCAN_PATTERN;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_SHOT_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_STORED_FILTERS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_SYSTEM_DESCRIPTION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_TEMPERATURE_CALCULATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_TIME_BASE;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_TRAJECTORY_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_TTIP_CONFIGURATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_VERTEX_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_VOXEL_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WAVEFORM_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WAVEFORM_SETTINGS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WINDOW_ANALYSIS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WINDOW_ECHO_CORRECTION;
end;

initialization

FixStringEncoding;
FillMetadataArray;

end.
